@@ -12,39 +12,39 @@ package java.util;
 
 import java.io.Serializable;
 
-public class ArrayList<T> extends AbstractList<T> implements List<T>, RandomAccess, Cloneable, Serializable {
+public class ArrayList<E> extends AbstractList<E> implements List<E>, RandomAccess, Cloneable, Serializable {
 	private static final long serialVersionUID = -2169998406647523911L;
 	public ArrayList(int i) {
 	}
 	public ArrayList() {
 	}
-	public T[] toArray(T[] o) {
+	public <T> T[] toArray(T[] o) {
 		return null;
 	}
 	public int size() {
 		return 0;
 	}
-	public boolean add(T o) {
+	public boolean add(E o) {
 		return false;
 	}
-	public int indexOf(T o) {
+	public int indexOf(E o) {
 		return 0;
 	}
-	public T remove(int index) {
+	public E remove(int index) {
 		return null;
 	}
-	public T get(int index) {
+	public E get(int index) {
 		return null;
 	}
-	public boolean contains(T o) {
+	public boolean contains(E o) {
 		return false;
 	}
-	public Iterator<T> iterator() {
+	public Iterator<E> iterator() {
 		return null;
 	}
-	public boolean addAll(Collection<T> c) {
+	public boolean addAll(Collection<E> c) {
 		return false;
 	}
-	public void set(int i, T o) {
+	public void set(int i, E o) {
 	}
 }
