@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2017, 2021 IBM Corporation.
+ * Copyright (c) 2017, 2022 IBM Corporation.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -57,6 +57,7 @@ import javax.tools.JavaFileObject;
 
 import org.eclipse.jdt.compiler.apt.tests.processors.base.BaseProcessor;
 import org.eclipse.jdt.compiler.apt.tests.processors.util.TestDirectiveVisitor;
+import org.eclipse.jdt.internal.compiler.classfmt.ClassFileConstants;
 import org.eclipse.jdt.internal.compiler.impl.CompilerOptions;
 
 /**
@@ -71,6 +72,8 @@ public class Java9ElementProcessor extends BaseProcessor {
 	boolean reportSuccessAlready = true;
 	RoundEnvironment roundEnv = null;
 	Messager _messager = null;
+	boolean isJre19;
+	boolean isJre18;
 	boolean isJre17;
 	boolean isJre12;
 	boolean isJre11;
@@ -93,12 +96,16 @@ public class Java9ElementProcessor extends BaseProcessor {
 		} else {
 			char c = '.';
 			if (property.indexOf(c) == -1) {
-				int ver12 = Integer.parseInt(CompilerOptions.VERSION_12);
-				int current = Integer.parseInt(property);
-				if (current >= ver12) {
-					int ver17 = Integer.parseInt(CompilerOptions.VERSION_17);
-					if (current >= ver17) {
+				int current = Integer.parseInt(property) + ClassFileConstants.MAJOR_VERSION_0;
+				if (current >= ClassFileConstants.MAJOR_VERSION_12) {
+					if (current >= ClassFileConstants.MAJOR_VERSION_17) {
 						this.isJre17 = true;
+						if (current >= ClassFileConstants.MAJOR_VERSION_18) {
+							this.isJre18 = true;
+							if (current >= ClassFileConstants.MAJOR_VERSION_19) {
+								this.isJre19 = true;
+							}
+						}
 					} else {
 						this.isJre12 = true;
 					}
@@ -184,6 +191,7 @@ public class Java9ElementProcessor extends BaseProcessor {
 		testUnnamedModule3();
 		testUnnamedModule4();
 		testUnnamedModule5();
+		testBug522472();
 	}
 
 	private Element getRoot(Element elem) {
@@ -498,7 +506,7 @@ public class Java9ElementProcessor extends BaseProcessor {
 		assertNotNull("java.base module null", base);
 		List<? extends Directive> directives = base.getDirectives();
 		List<Directive> filterDirective = filterDirective(directives, DirectiveKind.USES);
-		assertEquals("incorrect no of uses", (this.isJre11 || this.isJre12) ? 33 : 34, filterDirective.size());
+		assertEquals("incorrect no of uses", (this.isJre11 || this.isJre12) ? 33 : (this.isJre18 ? 35 : 34), filterDirective.size());
 	}
 	/*
 	 * Test java.base module can be loaded and verify its 'provides' attributes
@@ -917,6 +925,43 @@ public class Java9ElementProcessor extends BaseProcessor {
 		}
 		assertTrue("module not found", found);
 	}
+	public void testBug522472() {
+		Set<? extends Element> rootElements = this.roundEnv.getRootElements();
+		ModuleElement module = null;
+		for (Element element : rootElements) {
+			if (element instanceof ModuleElement) {
+				ModuleElement mod = (ModuleElement) element;
+				if (mod.getQualifiedName().toString().equals("mod.a")) {
+					module = mod;
+					break;
+				}
+			} else if (element instanceof TypeElement) {
+				Element root = getRoot(element);
+				if (root instanceof ModuleElement) {
+					ModuleElement mod = (ModuleElement) root;
+					if (mod.getQualifiedName().toString().equals("mod.a")) {
+						module = mod;
+						break;
+					}
+				}
+			}
+		}
+		assertNotNull("module should not be null", module);
+		List<? extends Element> elements = module.getEnclosedElements();
+		assertEquals("incorrect no of elements", 2, elements.size());
+		List<Element> packages = filterElements(elements, ElementKind.PACKAGE);
+//		ECJ fails the following tests. 
+		for (Element element : packages) {
+			Element enclosingElement = element.getEnclosingElement();
+			assertNotNull("module should not be null", enclosingElement);
+			assertEquals("module should be same", enclosingElement, module);
+		}
+		assertEquals("incorrect packages count", 2, packages.size());
+		List<? extends Directive> directives = module.getDirectives();
+		assertEquals("incorrect no of directives", 3, directives.size());
+		List<Directive> exports = filterDirective(directives, DirectiveKind.EXPORTS);
+		assertEquals("incorrect exports count", 2, exports.size());
+	}
 	private void validateModifiers(ExecutableElement method, Modifier[] expected) {
 		Set<Modifier> modifiers = method.getModifiers();
 		List<Modifier> list = new ArrayList<>(modifiers);
