@@ -23,4 +23,8 @@ import java.lang.annotation.Target;
 
 @Target({ElementType.TYPE_USE})
 @Retention(RetentionPolicy.RUNTIME)
-@interface MyAnnot5 {}
\ No newline at end of file
+@interface MyAnnot5 {}
+
+@Retention(RetentionPolicy.RUNTIME)
+@Target({ElementType.METHOD, ElementType.TYPE_USE})
+@interface MyAnnot6 {}
