@@ -2,7 +2,7 @@ package org.eclipse.jdt.compiler.apt.tests;
 import org.eclipse.jdt.compiler.apt.tests.annotations.Foo;
 import org.eclipse.jdt.compiler.apt.tests.annotations.FooContainer;
 
-@FooContainer({@Foo}) @Foo
-public class JEP120_3 {
+@FooContainer({@Foo, @Foo})
+public class JEP120_1 {
 	// ...
 }
\ No newline at end of file
