@@ -19,6 +19,7 @@ import java.io.IOException;
 import java.util.ArrayList;
 import java.util.List;
 
+import javax.lang.model.SourceVersion;
 import javax.tools.JavaCompiler;
 import javax.tools.ToolProvider;
 
@@ -31,112 +32,115 @@ public class RecordElementsTests extends TestCase {
 	private static final String MODULE_PROC = "org.eclipse.jdt.compiler.apt.tests.processors.elements.RecordElementProcessor";
 
 	public void testPreviewFlagTrue() throws IOException {
+		if (!isRunning17()) {
+			return;
+		}
 		JavaCompiler compiler = BatchTestUtils.getEclipseCompiler();
-		internalTestWithPreview(compiler, MODULE_PROC, "16", "testPreviewFlagTrue", null, "records", true);
+		internalTestWithPreview(compiler, MODULE_PROC, CompilerOptions.getLatestVersion(), "testPreviewFlagTrue", null, "records", true);
 	}
 	public void testRecords1() throws IOException {
 		JavaCompiler compiler = BatchTestUtils.getEclipseCompiler();
-		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords1", null, "records", true);
+		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords1", null, "records", false);
 	}
 	public void testRecords1Javac() throws Exception {
 		JavaCompiler compiler = ToolProvider.getSystemJavaCompiler();
-		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords1", null, "records", true);
+		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords1", null, "records", false);
 	}
 	public void testRecords2() throws IOException {
 		JavaCompiler compiler = BatchTestUtils.getEclipseCompiler();
-		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords2", null, "records", true);
+		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords2", null, "records", false);
 	}
 	public void testRecords2Javac() throws Exception {
 		JavaCompiler compiler = ToolProvider.getSystemJavaCompiler();
-		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords2", null, "records", true);
+		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords2", null, "records", false);
 	}
 	public void testRecords3() throws IOException {
 		JavaCompiler compiler = BatchTestUtils.getEclipseCompiler();
-		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords3", null, "records", true);
+		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords3", null, "records", false);
 	}
 	public void testRecords3Javac() throws Exception {
 		JavaCompiler compiler = ToolProvider.getSystemJavaCompiler();
-		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords3", null, "records", true);
+		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords3", null, "records", false);
 	}
 	public void testRecords3a() throws IOException {
 		JavaCompiler compiler = BatchTestUtils.getEclipseCompiler();
-		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords3a", null, "records", true);
+		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords3a", null, "records", false);
 	}
 	public void testRecords3aJavac() throws Exception {
 		JavaCompiler compiler = ToolProvider.getSystemJavaCompiler();
-		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords3a", null, "records", true);
+		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords3a", null, "records", false);
 	}
 	public void testRecords4() throws IOException {
 		JavaCompiler compiler = BatchTestUtils.getEclipseCompiler();
-		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords4", null, "records", true);
+		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords4", null, "records", false);
 	}
 	public void testRecords4Javac() throws Exception {
 		JavaCompiler compiler = ToolProvider.getSystemJavaCompiler();
-		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords4", null, "records", true);
+		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords4", null, "records", false);
 	}
 	public void testRecords4a() throws IOException {
 		JavaCompiler compiler = BatchTestUtils.getEclipseCompiler();
-		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords4a", null, "records", true, true);
+		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords4a", null, "records", false, true);
 	}
 	public void _testRecords4aJavac() throws Exception {
 		JavaCompiler compiler = ToolProvider.getSystemJavaCompiler();
-		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords4a", null, "records", true, true);
+		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords4a", null, "records", false, true);
 	}
 	public void testRecords5() throws IOException {
 		JavaCompiler compiler = BatchTestUtils.getEclipseCompiler();
-		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords5", null, "records", true);
+		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords5", null, "records", false);
 	}
 	public void testRecords5Javac() throws IOException {
 		JavaCompiler compiler = ToolProvider.getSystemJavaCompiler();
-		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords5", null, "records", true);
+		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords5", null, "records", false);
 	}
 	public void testRecords5a() throws IOException {
 		JavaCompiler compiler = BatchTestUtils.getEclipseCompiler();
-		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords5a", null, "records", true);
+		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords5a", null, "records", false);
 	}
 	public void testRecords5aJavac() throws IOException {
 		JavaCompiler compiler = ToolProvider.getSystemJavaCompiler();
-		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords5a", null, "records", true);
+		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords5a", null, "records", false);
 	}
 	public void testRecords6() throws IOException {
 		JavaCompiler compiler = BatchTestUtils.getEclipseCompiler();
-		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords6", null, "records", true);
+		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords6", null, "records", false);
 	}
 	public void testRecords6Javac() throws IOException {
 		JavaCompiler compiler = ToolProvider.getSystemJavaCompiler();
-		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords6", null, "records", true);
+		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords6", null, "records", false);
 	}
 	public void testRecords7() throws IOException {
 		JavaCompiler compiler = BatchTestUtils.getEclipseCompiler();
-		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords7", null, "records", true);
+		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords7", null, "records", false);
 	}
 	public void testRecords7Javac() throws IOException {
 		JavaCompiler compiler = ToolProvider.getSystemJavaCompiler();
-		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords7", null, "records", true);
+		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords7", null, "records", false);
 	}
 	public void testRecords8() throws IOException {
 		JavaCompiler compiler = BatchTestUtils.getEclipseCompiler();
-		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords8", null, "records", true);
+		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords8", null, "records", false);
 	}
 	public void testRecords8Javac() throws IOException {
 		JavaCompiler compiler = ToolProvider.getSystemJavaCompiler();
-		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords8", null, "records", true);
+		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords8", null, "records", false);
 	}
 	public void testRecords9() throws IOException {
 		JavaCompiler compiler = BatchTestUtils.getEclipseCompiler();
-		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords9", null, "records", true);
+		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords9", null, "records", false);
 	}
 	public void testRecords9Javac() throws IOException {
 		JavaCompiler compiler = ToolProvider.getSystemJavaCompiler();
-		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords9", null, "records", true);
+		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords9", null, "records", false);
 	}
 	public void testRecords10() throws IOException {
 		JavaCompiler compiler = BatchTestUtils.getEclipseCompiler();
-		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords10", null, "records", true);
+		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords10", null, "records", false);
 	}
 	public void testRecords10Javac() throws IOException {
 		JavaCompiler compiler = ToolProvider.getSystemJavaCompiler();
-		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords10", null, "records", true);
+		internalTestWithPreview(compiler, MODULE_PROC, "16", "testRecords10", null, "records", false);
 	}
 
 	protected void internalTestWithPreview(JavaCompiler compiler, String processor, String compliance,
@@ -174,9 +178,21 @@ public class RecordElementsTests extends TestCase {
 		// if not, it will set it to an error value.
 		assertEquals("succeeded", System.getProperty(processor));
 	}
+	public boolean isRunning17() {
+		try {
+			SourceVersion.valueOf("RELEASE_17");
+		} catch(IllegalArgumentException iae) {
+			return false;
+		}
+		return true;
+	}
 	public boolean isRunning16() {
-		String specVersion = System.getProperty("java.specification.version");
-		return CompilerOptions.VERSION_16.equals(specVersion);
+		try {
+			SourceVersion.valueOf("RELEASE_16");
+		} catch(IllegalArgumentException iae) {
+			return false;
+		}
+		return true;
 	}
 	/* (non-Javadoc)
 	 * @see junit.framework.TestCase#setUp()
