@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2006, 2017 BEA Systems, Inc. and others
+ * Copyright (c) 2006, 2022 BEA Systems, Inc. and others
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -7,7 +7,7 @@
  * https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- * 
+ *
  * Contributors:
  *    wharley@bea.com - initial API and implementation
  *    IBM Corporation - Fix for bug 341494
@@ -36,6 +36,7 @@ import javax.lang.model.element.AnnotationValue;
 import javax.lang.model.element.Element;
 import javax.lang.model.element.ElementKind;
 import javax.lang.model.element.ExecutableElement;
+import javax.lang.model.element.ModuleElement;
 import javax.lang.model.element.Name;
 import javax.lang.model.element.PackageElement;
 import javax.lang.model.element.TypeElement;
@@ -54,6 +55,7 @@ import org.eclipse.jdt.internal.compiler.lookup.LocalVariableBinding;
 import org.eclipse.jdt.internal.compiler.lookup.LookupEnvironment;
 import org.eclipse.jdt.internal.compiler.lookup.MethodBinding;
 import org.eclipse.jdt.internal.compiler.lookup.MethodVerifier;
+import org.eclipse.jdt.internal.compiler.lookup.ModuleBinding;
 import org.eclipse.jdt.internal.compiler.lookup.PackageBinding;
 import org.eclipse.jdt.internal.compiler.lookup.ParameterizedTypeBinding;
 import org.eclipse.jdt.internal.compiler.lookup.ReferenceBinding;
@@ -64,7 +66,7 @@ import org.eclipse.jdt.internal.compiler.lookup.TypeConstants;
 /**
  * Utilities for working with java8 and earlier language elements.
  * There is one of these for every ProcessingEnvironment.
- * 
+ *
  * @see ElementsImpl9
  */
 public class ElementsImpl implements Elements {
@@ -347,6 +349,7 @@ public class ElementsImpl implements Elements {
 			case CLASS :
 			case ENUM :
 			case INTERFACE :
+			case RECORD :
 				TypeElementImpl typeElementImpl = (TypeElementImpl) e;
 				ReferenceBinding referenceBinding = (ReferenceBinding)typeElementImpl._binding;
 				if (referenceBinding instanceof SourceTypeBinding) {
@@ -377,6 +380,7 @@ public class ElementsImpl implements Elements {
 					referenceContext = sourceMethod;
 				}
 				break;
+			case RECORD_COMPONENT :
 			case ENUM_CONSTANT :
 			case FIELD :
 				VariableElementImpl variableElementImpl = (VariableElementImpl) e;
@@ -502,7 +506,7 @@ public class ElementsImpl implements Elements {
 						}
 				}
 			}
-			
+
 			// append a newline at the end of each line except the last, even if we skipped the last entirely
 			int end = lines.length - 1;
 			if (line < end) {
@@ -516,7 +520,7 @@ public class ElementsImpl implements Elements {
 
 	/**
 	 * Returns the index of the last leading stars on this line, -1 if none.
-	 * 
+	 *
 	 * @param line the given line
 	 * @return the computed index
 	 */
@@ -582,6 +586,7 @@ public class ElementsImpl implements Elements {
 			case CLASS :
 			case ENUM :
 			case INTERFACE :
+			case RECORD :
 				TypeElementImpl typeElementImpl = (TypeElementImpl) type;
 				ReferenceBinding referenceBinding = (ReferenceBinding)typeElementImpl._binding;
 				return (PackageElement) _env.getFactory().newElement(referenceBinding.fPackage);
@@ -594,6 +599,7 @@ public class ElementsImpl implements Elements {
 				return (PackageElement) _env.getFactory().newElement(methodBinding.declaringClass.fPackage);
 			case ENUM_CONSTANT :
 			case FIELD :
+			case RECORD_COMPONENT :
 				VariableElementImpl variableElementImpl = (VariableElementImpl) type;
 				FieldBinding fieldBinding = (FieldBinding) variableElementImpl._binding;
 				return (PackageElement) _env.getFactory().newElement(fieldBinding.declaringClass.fPackage);
@@ -649,6 +655,9 @@ public class ElementsImpl implements Elements {
 		if (null == binding) {
 			return null;
 		}
+		if((binding.tagBits & TagBits.HasMissingType) != 0) {
+			return null;
+		}
 		return new TypeElementImpl(_env, binding, null);
 	}
 
@@ -722,5 +731,9 @@ public class ElementsImpl implements Elements {
 		}
 		return false;
 	}
-
+	@Override
+    public boolean isAutomaticModule(ModuleElement module) {
+		ModuleBinding binding = ((ModuleElementImpl) module).binding;
+		return binding != null ? binding.isAutomatic() : false;
+    }
 }
