@@ -45,6 +45,7 @@ import org.eclipse.jdt.internal.compiler.lookup.ParameterizedTypeBinding;
 import org.eclipse.jdt.internal.compiler.lookup.ReferenceBinding;
 import org.eclipse.jdt.internal.compiler.lookup.TypeBinding;
 import org.eclipse.jdt.internal.compiler.lookup.TypeVariableBinding;
+import org.eclipse.jdt.internal.compiler.lookup.VariableBinding;
 
 /**
  * Utilities for working with types (as opposed to elements).
@@ -122,7 +123,7 @@ public class TypesImpl implements Types {
 							if (typeVariables.length == typeArguments.length) {
 								for(int i = 0; i < typeVariables.length; i++) {
 									if (typeVariables[i] == memberBinding) {
-										return TypesImpl.this._env.getFactory().newTypeMirror(typeArguments[i]); 
+										return TypesImpl.this._env.getFactory().newTypeMirror(typeArguments[i]);
 									}
 								}
 							}
@@ -138,12 +139,13 @@ public class TypesImpl implements Types {
 			break;
 		case FIELD:
 		case ENUM_CONSTANT:
+		case RECORD_COMPONENT:
 			typeMirror = findMemberInHierarchy(referenceBinding, elementImpl._binding, new MemberInTypeFinder() {
 				@Override
 				public TypeMirror find(ReferenceBinding typeBinding, Binding memberBinding) {
-					FieldBinding fieldBinding = (FieldBinding) memberBinding;
+					VariableBinding variableBinding = (VariableBinding) memberBinding;
 					for (FieldBinding field : typeBinding.fields()) {
-						if (CharOperation.equals(field.name, fieldBinding.name)) {
+						if (CharOperation.equals(field.name, variableBinding.name)) {
 							return TypesImpl.this._env.getFactory().newTypeMirror(field);
 						}
 					}
@@ -159,7 +161,7 @@ public class TypesImpl implements Types {
 		case ANNOTATION_TYPE:
 		case INTERFACE:
 		case CLASS:
-
+		case RECORD:
 			typeMirror = findMemberInHierarchy(referenceBinding, elementImpl._binding, new MemberInTypeFinder() {
 				@Override
 				public TypeMirror find(ReferenceBinding typeBinding, Binding memberBinding) {
@@ -335,7 +337,7 @@ public class TypesImpl implements Types {
         int typeVariablesLength = typeVariables.length;
         if (typeArgsLength == 0) {
             if (elementBinding.isGenericType()) {
-                // per javadoc, 
+                // per javadoc,
                 return (DeclaredType) _env.getFactory().newTypeMirror(this._env.getLookupEnvironment().createRawType(elementBinding, null));
             }
             return (DeclaredType)typeElem.asType();
@@ -362,7 +364,7 @@ public class TypesImpl implements Types {
     }
 
     /* (non-Javadoc)
-     * Create a specific type from a member element. The containing type can be parameterized, 
+     * Create a specific type from a member element. The containing type can be parameterized,
      * e.g. Outer<String>.Inner, but it cannot be generic, i.e., Outer<T>.Inner. It only makes
      * sense to use this method when the member element is parameterized by its container; so,
      * for example, it makes sense for an inner class but not for a static member class.
