@@ -62,7 +62,7 @@ public void checkParse(
 		}
 	}
 
-	StringBuffer buffer = new StringBuffer(100);
+	StringBuilder buffer = new StringBuilder(100);
 	if (compilationResult.hasProblems() || compilationResult.hasTasks()) {
 		CategorizedProblem[] problems = compilationResult.getAllProblems();
 		int count = problems.length;
