@@ -54,7 +54,7 @@ public void checkParse(
 
 	parser.parse(sourceUnit, compilationResult);
 
-	StringBuffer buffer = new StringBuffer(100);
+	StringBuilder buffer = new StringBuilder(100);
 	if (compilationResult.hasProblems() || compilationResult.hasTasks()) {
 		CategorizedProblem[] problems = compilationResult.getAllProblems();
 		int count = problems.length;
