@@ -62,12 +62,13 @@ public class ASTConverter13Test extends ConverterTestSetup {
 	static {
 //		TESTS_NUMBERS = new int[] { 19 };
 //		TESTS_RANGE = new int[] { 1, -1 };
-//		TESTS_NAMES = new String[] {"test0001"};
+//		TESTS_NAMES = new String[] {"_test0001"};
 	}
 	public static Test suite() {
 		return buildModelTestSuite(ASTConverter13Test.class);
 	}
-	
+
+	@SuppressWarnings("deprecation")
 	static int getAST13() {
 		return AST.JLS13;
 	}
@@ -81,21 +82,21 @@ public class ASTConverter13Test extends ConverterTestSetup {
 	/*
 	 * Test that a simple switch expression's return type holds the correct type
 	 */
-	public void test0001() throws JavaModelException {
+	public void _test0001() throws JavaModelException {
 		String contents =
 			"	public class X {\n" +
 			"   enum Day\n" +
-			"   {\n" + 
-			"   	SUNDAY, MONDAY, TUESDAY, WEDNESDAY,\n" + 
-			"   	THURSDAY, FRIDAY, SATURDAY;\n" + 
+			"   {\n" +
+			"   	SUNDAY, MONDAY, TUESDAY, WEDNESDAY,\n" +
+			"   	THURSDAY, FRIDAY, SATURDAY;\n" +
 			"	}\n" +
-			"	public static void main(String[] args) {\n" + 
+			"	public static void main(String[] args) {\n" +
 			"		Day day = Day.SUNDAY;\n" +
-			"		int k = switch (day) {\n" + 
-			"    	case MONDAY  -> throw new NullPointerException();\n" + 
-			"    	case TUESDAY -> 1;\n" + 
-			"\n" +     
-			"	 	case WEDNESDAY -> {yield 10;}\n" + 
+			"		int k = switch (day) {\n" +
+			"    	case MONDAY  -> throw new NullPointerException();\n" +
+			"    	case TUESDAY -> 1;\n" +
+			"\n" +
+			"	 	case WEDNESDAY -> {yield 10;}\n" +
 			"    	default      -> {\n" +
 			"        	int g = day.toString().length();\n" +
 			"        	yield g;\n" +
@@ -130,37 +131,37 @@ public class ASTConverter13Test extends ConverterTestSetup {
 	 * Test that a case statement with multiple cases is resolved correctly
 	 * and has the correct source range
 	 */
-	public void test0002() throws JavaModelException {
+	public void _test0002() throws JavaModelException {
 		String contents =
-			"public class X {\n" + 
-			"	static enum Day {MONDAY,TUESDAY,WEDNESDAY,THURSDAY,FRIDAY, SATURDAY,SUNDAY}\n" + 
-			"	String aa(Day day) throws Exception {\n" + 
-			"		var today = \"\";\n" + 
-			"		switch (day) {\n" + 
-			"			case SATURDAY,SUNDAY ->\n" + 
-			"				today=\"Weekend\";\n" + 
-			"			case MONDAY,TUESDAY,WEDNESDAY,THURSDAY,FRIDAY ->\n" + 
-			"				today=\"Working\";\n" + 
-			"			default ->\n" + 
-			"				throw new Exception(\"Invalid day: \" + day.name());\n" + 
-			"		}\n" + 
-			"		return today;\n" + 
-			"	}\n" + 
-			"	\n" + 
-			"	String bb(Day day) throws Exception {\n" + 
-			"		var today = \"\";\n" + 
-			"		switch (day) {\n" + 
-			"			case SATURDAY,SUNDAY:\n" + 
-			"				today = \"Weekend day\";\n" + 
-			"				break;\n" + 
-			"			case MONDAY,TUESDAY,WEDNESDAY,THURSDAY,FRIDAY:\n" + 
-			"				today = \"Working day\";\n" + 
-			"				break;\n" + 
-			"			default:\n" + 
-			"				throw new Exception(\"Invalid day: \" + day.name());\n" + 
-			"		}\n" + 
-			"		return today;\n" + 
-			"	}\n" + 
+			"public class X {\n" +
+			"	static enum Day {MONDAY,TUESDAY,WEDNESDAY,THURSDAY,FRIDAY, SATURDAY,SUNDAY}\n" +
+			"	String aa(Day day) throws Exception {\n" +
+			"		var today = \"\";\n" +
+			"		switch (day) {\n" +
+			"			case SATURDAY,SUNDAY ->\n" +
+			"				today=\"Weekend\";\n" +
+			"			case MONDAY,TUESDAY,WEDNESDAY,THURSDAY,FRIDAY ->\n" +
+			"				today=\"Working\";\n" +
+			"			default ->\n" +
+			"				throw new Exception(\"Invalid day: \" + day.name());\n" +
+			"		}\n" +
+			"		return today;\n" +
+			"	}\n" +
+			"	\n" +
+			"	String bb(Day day) throws Exception {\n" +
+			"		var today = \"\";\n" +
+			"		switch (day) {\n" +
+			"			case SATURDAY,SUNDAY:\n" +
+			"				today = \"Weekend day\";\n" +
+			"				break;\n" +
+			"			case MONDAY,TUESDAY,WEDNESDAY,THURSDAY,FRIDAY:\n" +
+			"				today = \"Working day\";\n" +
+			"				break;\n" +
+			"			default:\n" +
+			"				throw new Exception(\"Invalid day: \" + day.name());\n" +
+			"		}\n" +
+			"		return today;\n" +
+			"	}\n" +
 			"}" ;
 		this.workingCopy = getWorkingCopy("/Converter13/src/X.java", true/*resolve*/);
 		IJavaProject javaProject = this.workingCopy.getJavaProject();
@@ -183,10 +184,10 @@ public class ASTConverter13Test extends ConverterTestSetup {
 			javaProject.setOption(JavaCore.COMPILER_PB_ENABLE_PREVIEW_FEATURES, old);
 		}
 	}
-	
+
 	/* test implicit break statement */
 
-	public void test0003() throws JavaModelException {
+	public void _test0003() throws JavaModelException {
 		String contents =
 			"public class X {\n" +
 			"	static enum Day {MONDAY,TUESDAY,WEDNESDAY,THURSDAY,FRIDAY, SATURDAY,SUNDAY}\n" +
@@ -232,12 +233,12 @@ public class ASTConverter13Test extends ConverterTestSetup {
 				assertEquals("Switch statement", node.getNodeType(), ASTNode.SWITCH_STATEMENT);
 				SwitchStatement switchStatement = (SwitchStatement) node;
 				checkSourceRange((Statement) switchStatement.statements().get(0), "case SATURDAY,SUNDAY ->", contents);
-			
+
 		} finally {
 			javaProject.setOption(JavaCore.COMPILER_PB_ENABLE_PREVIEW_FEATURES, old);
 		}
 	}
-	public void test0004() throws JavaModelException {
+	public void _test0004() throws JavaModelException {
 		String contents =
 				"public class X {\n" +
 				"	static enum Day {MONDAY,TUESDAY,WEDNESDAY,THURSDAY,FRIDAY, SATURDAY,SUNDAY}\n" +
@@ -283,7 +284,7 @@ public class ASTConverter13Test extends ConverterTestSetup {
 				Expression expression2 = brStmt.getExpression();
 				assertNotNull("should not null", expression2);
 				assertEquals("incorrect node type", ASTNode.STRING_LITERAL, expression2.getNodeType());
-				
+
 				//default case:
 				SwitchCase caseStmt = (SwitchCase) statements.get(4);
 				assertTrue("not default", caseStmt.isDefault());
@@ -291,23 +292,23 @@ public class ASTConverter13Test extends ConverterTestSetup {
 				expression2 = brStmt.getExpression();
 				assertNotNull("should not null", expression2);
 				assertEquals("incorrect node type", ASTNode.STRING_LITERAL, expression2.getNodeType());
-			
+
 		} finally {
 			javaProject.setOption(JavaCore.COMPILER_PB_ENABLE_PREVIEW_FEATURES, old);
 		}
 	}
 	@Deprecated
-	public void _test0005() throws JavaModelException {
+	public void __test0005() throws JavaModelException {
 		String contents =
 				"public class X {\n" +
-				"	public String test001() {\n" + 
-				"		int i = 0;\n" + 
-				"		String ret = switch(i%2) {\n" + 
-				"		case 0 -> \"odd\";\n" + 
-				"		case 1 -> \"even\";\n" + 
-				"		default -> \"\";\n" + 
-				"		};\n" + 
-				"		return ret;\n" + 
+				"	public String _test001() {\n" +
+				"		int i = 0;\n" +
+				"		String ret = switch(i%2) {\n" +
+				"		case 0 -> \"odd\";\n" +
+				"		case 1 -> \"even\";\n" +
+				"		default -> \"\";\n" +
+				"		};\n" +
+				"		return ret;\n" +
 				"	}" +
 				"}" ;
 		this.workingCopy = getWorkingCopy("/Converter13/src/X.java", true/*resolve*/);
@@ -347,22 +348,22 @@ public class ASTConverter13Test extends ConverterTestSetup {
 				expression2 = brStmt.getExpression();
 				assertNotNull("should not null", expression2);
 				assertEquals("incorrect node type", ASTNode.STRING_LITERAL, expression2.getNodeType());
-			
+
 		} finally {
 			javaProject.setOption(JavaCore.COMPILER_PB_ENABLE_PREVIEW_FEATURES, old);
 		}
 	}
-	public void test0006() throws JavaModelException {
+	public void _test0006() throws JavaModelException {
 		String contents =
 				"public class X {\n" +
-						"	public String test001() {\n" + 
-						"		int i = 0;\n" + 
-						"		String ret = switch(i%2) {\n" + 
-						"		case 0 -> {return \"odd\"; }\n" + 
-						"		case 1 -> \"even\";\n" + 
-						"		default -> \"\";\n" + 
-						"		};\n" + 
-						"		return ret;\n" + 
+						"	public String _test001() {\n" +
+						"		int i = 0;\n" +
+						"		String ret = switch(i%2) {\n" +
+						"		case 0 -> {return \"odd\"; }\n" +
+						"		case 1 -> \"even\";\n" +
+						"		default -> \"\";\n" +
+						"		};\n" +
+						"		return ret;\n" +
 						"	}" +
 						"}" ;
 		this.workingCopy = getWorkingCopy("/Converter13/src/X.java", true/*resolve*/);
@@ -398,7 +399,8 @@ public class ASTConverter13Test extends ConverterTestSetup {
 		}
 	}
 	// Moved over from ASTConverter9Test
-	public void testBug531714_015() throws CoreException {
+	@SuppressWarnings("deprecation")
+	public void _testBug531714_015() throws CoreException {
 		// saw NPE in SwitchExpression.resolveType(SwitchExpression.java:423)
 		if (!isJRE13) {
 			System.err.println("Test "+getName()+" requires a JRE 13");
@@ -411,19 +413,19 @@ public class ASTConverter13Test extends ConverterTestSetup {
 			String source =
 				"import java.util.*;\n" +
 				"public class X {\n" +
-				"	void testForeach1(int i, List<String> list) {\n" + 
-				"		for (String s : switch(i) { case 1 -> list; default -> ; }) {\n" + 
-				"			\n" + 
+				"	void testForeach1(int i, List<String> list) {\n" +
+				"		for (String s : switch(i) { case 1 -> list; default -> ; }) {\n" +
+				"			\n" +
 				"		}\n" +
 				"		Throwable t = switch (i) {\n" +
 				"			case 1 -> new Exception();\n" +
 				"			case 2 -> new RuntimeException();\n" + // trigger !typeUniformAcrossAllArms
 				"			default -> missing;\n" +
 				"		};\n" +
-				"	}\n" + 
+				"	}\n" +
 				"	void testForeach0(int i, List<String> list) {\n" + // errors in first arm
-				"		for (String s : switch(i) { case 1 -> ; default -> list; }) {\n" + 
-				"			\n" + 
+				"		for (String s : switch(i) { case 1 -> ; default -> list; }) {\n" +
+				"			\n" +
 				"		}\n" +
 				"		Throwable t = switch (i) {\n" +
 				"			case 0 -> missing;\n" +
@@ -440,7 +442,7 @@ public class ASTConverter13Test extends ConverterTestSetup {
 				"}\n";
 			createFile("Foo/src/X.java", source);
 			ICompilationUnit cuD = getCompilationUnit("/Foo/src/X.java");
-				
+
 			ASTParser parser = ASTParser.newParser(AST_INTERNAL_JLS13);
 			parser.setProject(p);
 			parser.setSource(cuD);
@@ -450,55 +452,55 @@ public class ASTConverter13Test extends ConverterTestSetup {
 			org.eclipse.jdt.core.dom.CompilationUnit cuAST = (org.eclipse.jdt.core.dom.CompilationUnit) parser.createAST(null);
 			IProblem[] problems = cuAST.getProblems();
 			assertProblems("Unexpected problems",
-					"1. ERROR in /Foo/src/X.java (at line 4)\n" + 
-					"	for (String s : switch(i) { case 1 -> list; default -> ; }) {\n" + 
-					"	                                                    ^^\n" + 
-					"Syntax error on token \"->\", Expression expected after this token\n" + 
-					"----------\n" + 
-					"2. ERROR in /Foo/src/X.java (at line 10)\n" + 
-					"	default -> missing;\n" + 
-					"	           ^^^^^^^\n" + 
-					"missing cannot be resolved to a variable\n" + 
-					"----------\n" + 
-					"3. ERROR in /Foo/src/X.java (at line 14)\n" + 
-					"	for (String s : switch(i) { case 1 -> ; default -> list; }) {\n" + 
-					"	                                   ^^\n" + 
-					"Syntax error on token \"->\", Expression expected after this token\n" + 
-					"----------\n" + 
-					"4. ERROR in /Foo/src/X.java (at line 18)\n" + 
-					"	case 0 -> missing;\n" + 
-					"	          ^^^^^^^\n" + 
-					"missing cannot be resolved to a variable\n" + 
-					"----------\n" + 
-					"5. ERROR in /Foo/src/X.java (at line 25)\n" + 
-					"	case 0 -> missing;\n" + 
-					"	          ^^^^^^^\n" + 
-					"missing cannot be resolved to a variable\n" + 
-					"----------\n" + 
-					"6. ERROR in /Foo/src/X.java (at line 26)\n" + 
-					"	default -> absent;\n" + 
-					"	           ^^^^^^\n" + 
-					"absent cannot be resolved to a variable\n" + 
+					"1. ERROR in /Foo/src/X.java (at line 4)\n" +
+					"	for (String s : switch(i) { case 1 -> list; default -> ; }) {\n" +
+					"	                                                    ^^\n" +
+					"Syntax error on token \"->\", Expression expected after this token\n" +
+					"----------\n" +
+					"2. ERROR in /Foo/src/X.java (at line 10)\n" +
+					"	default -> missing;\n" +
+					"	           ^^^^^^^\n" +
+					"missing cannot be resolved to a variable\n" +
+					"----------\n" +
+					"3. ERROR in /Foo/src/X.java (at line 14)\n" +
+					"	for (String s : switch(i) { case 1 -> ; default -> list; }) {\n" +
+					"	                                   ^^\n" +
+					"Syntax error on token \"->\", Expression expected after this token\n" +
+					"----------\n" +
+					"4. ERROR in /Foo/src/X.java (at line 18)\n" +
+					"	case 0 -> missing;\n" +
+					"	          ^^^^^^^\n" +
+					"missing cannot be resolved to a variable\n" +
+					"----------\n" +
+					"5. ERROR in /Foo/src/X.java (at line 25)\n" +
+					"	case 0 -> missing;\n" +
+					"	          ^^^^^^^\n" +
+					"missing cannot be resolved to a variable\n" +
+					"----------\n" +
+					"6. ERROR in /Foo/src/X.java (at line 26)\n" +
+					"	default -> absent;\n" +
+					"	           ^^^^^^\n" +
+					"absent cannot be resolved to a variable\n" +
 					"----------\n",
 					problems, source.toCharArray());
 		} finally {
 			deleteProject(p);
 		}
 	}
-	
-	public void test0007() throws JavaModelException {
+
+	public void _test0007() throws JavaModelException {
 		String contents =
 				"public class X {\n" +
-						"	public String test001() {\n" + 
-						"		String s = \"\"\"\n" + 
-						"      	<html>\n" + 
-						"        <body>\n" + 
-						"            <p>Hello, world</p>\n" + 
-						"        </body>\n" + 
-						"    	</html>\n" + 
-						"    	\"\"\";\n" + 
+						"	public String _test001() {\n" +
+						"		String s = \"\"\"\n" +
+						"      	<html>\n" +
+						"        <body>\n" +
+						"            <p>Hello, world</p>\n" +
+						"        </body>\n" +
+						"    	</html>\n" +
+						"    	\"\"\";\n" +
 						"    	System.out.println(s);" +
-						"		return s;\n" + 
+						"		return s;\n" +
 						"	}" +
 						"}" ;
 		this.workingCopy = getWorkingCopy("/Converter13/src/X.java", true/*resolve*/);
@@ -526,14 +528,14 @@ public class ASTConverter13Test extends ConverterTestSetup {
 
 			assertTrue("String should not be empty", escapedValue.length() != 0);
 			assertTrue("String should start with \"\"\"", escapedValue.startsWith("\"\"\""));
-			
+
 			String literal = ((TextBlock) initializer).getLiteralValue();
-			assertEquals("literal value not correct", 
-					"      	<html>\n" + 
-					"        <body>\n" + 
-					"            <p>Hello, world</p>\n" + 
-					"        </body>\n" + 
-					"    	</html>\n" + 
+			assertEquals("literal value not correct",
+					"      	<html>\n" +
+					"        <body>\n" +
+					"            <p>Hello, world</p>\n" +
+					"        </body>\n" +
+					"    	</html>\n" +
 					"    	",
 					literal);
 
@@ -541,19 +543,19 @@ public class ASTConverter13Test extends ConverterTestSetup {
 			javaProject.setOption(JavaCore.COMPILER_PB_ENABLE_PREVIEW_FEATURES, old);
 		}
 	}
-	public void test0008() throws JavaModelException {
+	public void _test0008() throws JavaModelException {
 		String contents =
 				"public class X {\n" +
-						"	public String test001() {\n" + 
-						"		String s = \"\"\"\n" + 
-						"      	<html>\n" + 
-						"        <body>\n" + 
-						"            <p>Hello, world</p>\n" + 
-						"        </body>\n" + 
-						"    	</html>\n" + 
-						"    	\"\"\";\n" + 
+						"	public String _test001() {\n" +
+						"		String s = \"\"\"\n" +
+						"      	<html>\n" +
+						"        <body>\n" +
+						"            <p>Hello, world</p>\n" +
+						"        </body>\n" +
+						"    	</html>\n" +
+						"    	\"\"\";\n" +
 						"    	System.out.println(s);" +
-						"		return s;\n" + 
+						"		return s;\n" +
 						"	}" +
 						"}" ;
 		this.workingCopy = getWorkingCopy("/Converter13/src/X.java", true/*resolve*/);
@@ -578,19 +580,19 @@ public class ASTConverter13Test extends ConverterTestSetup {
 			javaProject.setOption(JavaCore.COMPILER_PB_ENABLE_PREVIEW_FEATURES, old);
 		}
 	}
-	public void test0009() throws JavaModelException {
+	public void _test0009() throws JavaModelException {
 		String contents =
 				"public class X {\n" +
-						"	public String test001() {\n" + 
-						"		String s = \"\"\"\n" + 
-						"      	<html>\n" + 
-						"        <body>\n" + 
-						"            <p>Hello, world</p>\n" + 
-						"        </body>\n" + 
-						"    	</html>\n" + 
-						"    	\"\"\";\n" + 
+						"	public String _test001() {\n" +
+						"		String s = \"\"\"\n" +
+						"      	<html>\n" +
+						"        <body>\n" +
+						"            <p>Hello, world</p>\n" +
+						"        </body>\n" +
+						"    	</html>\n" +
+						"    	\"\"\";\n" +
 						"    	System.out.println(s);" +
-						"		return s;\n" + 
+						"		return s;\n" +
 						"	}" +
 						"}" ;
 		this.workingCopy = getWorkingCopy("/Converter13/src/X.java", true/*resolve*/);
@@ -617,46 +619,46 @@ public class ASTConverter13Test extends ConverterTestSetup {
 			ITypeBinding binding = initializer.resolveTypeBinding();
 			assertNotNull("No binding", binding);
 			assertEquals("Wrong qualified name", "java.lang.String", binding.getQualifiedName());
-			
+
 			String escapedValue = ((TextBlock) initializer).getEscapedValue();
 
 			assertTrue("String should not be empty", escapedValue.length() != 0);
 			assertTrue("String should start with \"\"\"", escapedValue.startsWith("\"\"\""));
-			assertEquals("escaped value not correct", 
-					"\"\"\"\n" + 
-					"      	<html>\n" + 
-					"        <body>\n" + 
-					"            <p>Hello, world</p>\n" + 
-					"        </body>\n" + 
-					"    	</html>\n" + 
-					"    	\"\"\"", 
+			assertEquals("escaped value not correct",
+					"\"\"\"\n" +
+					"      	<html>\n" +
+					"        <body>\n" +
+					"            <p>Hello, world</p>\n" +
+					"        </body>\n" +
+					"    	</html>\n" +
+					"    	\"\"\"",
 					escapedValue);
-			
+
 			String literal = ((TextBlock) initializer).getLiteralValue();
-			assertEquals("literal value not correct", 
-					"      	<html>\n" + 
-					"        <body>\n" + 
-					"            <p>Hello, world</p>\n" + 
-					"        </body>\n" + 
-					"    	</html>\n" + 
-					"    	", 
+			assertEquals("literal value not correct",
+					"      	<html>\n" +
+					"        <body>\n" +
+					"            <p>Hello, world</p>\n" +
+					"        </body>\n" +
+					"    	</html>\n" +
+					"    	",
 					literal);
 		} finally {
 			javaProject.setOption(JavaCore.COMPILER_PB_ENABLE_PREVIEW_FEATURES, old);
 		}
 	}
-	public void test0010() throws JavaModelException {
+	public void _test0010() throws JavaModelException {
 		String contents =
-				"public class test13 {\n" + 
-				"	public static void main(String[] args) {\n" + 
-				"		String s = \"\"\"\n" + 
-				"				nadknaks vgvh \n" + 
-				"				\"\"\";\n" + 
-				"\n" + 
-				"		int m = 10;\n" + 
-				"		m = m* 6;\n" + 
-				"		System.out.println(s);\n" + 
-				"	}\n" + 
+				"public class test13 {\n" +
+				"	public static void main(String[] args) {\n" +
+				"		String s = \"\"\"\n" +
+				"				nadknaks vgvh \n" +
+				"				\"\"\";\n" +
+				"\n" +
+				"		int m = 10;\n" +
+				"		m = m* 6;\n" +
+				"		System.out.println(s);\n" +
+				"	}\n" +
 				"}" ;
 		this.workingCopy = getWorkingCopy("/Converter13/src/test13.java", true/*resolve*/);
 		IJavaProject javaProject = this.workingCopy.getJavaProject();
@@ -682,31 +684,31 @@ public class ASTConverter13Test extends ConverterTestSetup {
 			javaProject.setOption(JavaCore.COMPILER_PB_ENABLE_PREVIEW_FEATURES, old);
 		}
 	}
-	
-		public void test0011() throws CoreException {
+
+		public void _test0011() throws CoreException {
 			// saw NPE in SwitchExpression.resolveType(SwitchExpression.java:423)
 			if (!isJRE13) {
 				System.err.println("Test "+getName()+" requires a JRE 13");
 				return;
 			}
 			String source =
-				"public class Switch {\n" + 
-				"	public static void main(String[] args) {\n" + 
-				"		foo(Day.TUESDAY);\n" + 
-				"	}\n" + 
-				"\n" + 
-				"	@SuppressWarnings(\"preview\")\n" + 
-				"	private static void foo(Day day) {\n" + 
-				"		switch (day) {\n" + 
-				"		case SUNDAY, MONDAY, FRIDAY -> System.out.println(6);\n" + 
-				"		case TUESDAY -> System.out.println(7);\n" + 
-				"		case THURSDAY, SATURDAY -> System.out.println(8);\n" + 
-				"		}\n" + 
-				"	}\n" + 
-				"}\n" + 
-				"\n" + 
-				"enum Day {\n" + 
-				"	MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY;\n" + 
+				"public class Switch {\n" +
+				"	public static void main(String[] args) {\n" +
+				"		foo(Day.TUESDAY);\n" +
+				"	}\n" +
+				"\n" +
+				"	@SuppressWarnings(\"preview\")\n" +
+				"	private static void foo(Day day) {\n" +
+				"		switch (day) {\n" +
+				"		case SUNDAY, MONDAY, FRIDAY -> System.out.println(6);\n" +
+				"		case TUESDAY -> System.out.println(7);\n" +
+				"		case THURSDAY, SATURDAY -> System.out.println(8);\n" +
+				"		}\n" +
+				"	}\n" +
+				"}\n" +
+				"\n" +
+				"enum Day {\n" +
+				"	MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY;\n" +
 				"}\n";
 			this.workingCopy = getWorkingCopy("/Converter13/src/Switch.java", true/*resolve*/);
 			IJavaProject javaProject = this.workingCopy.getJavaProject();
