@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2020 IBM Corporation and others.
+ * Copyright (c) 2020, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -111,7 +111,7 @@ public class ASTConverterJavadocTest_15 extends ConverterTestSetup {
 	protected boolean resolveBinding = true;
 	protected boolean packageBinding = true;
 	// AST Level
-	protected int astLevel = AST.JLS15;
+	protected int astLevel = AST.getJLSLatest();
 	protected int savedLevel;
 	// Debug
 	protected String prefix = "";
@@ -332,7 +332,7 @@ public class ASTConverterJavadocTest_15 extends ConverterTestSetup {
 	protected void setSourceComment(char[] source) throws ArrayIndexOutOfBoundsException {
 		this.comments = new ArrayList();
 		this.allTags = new ArrayList();
-		StringBuffer buffer = null;
+		StringBuilder buffer = null;
 		int comment = 0;
 		boolean end = false, lineStarted = false;
 		String tag = null;
@@ -356,7 +356,7 @@ public class ASTConverterJavadocTest_15 extends ConverterTestSetup {
 					switch (currentChar) {
 						case '/':
 							comment = 1; // first char for comments...
-							buffer = new StringBuffer();
+							buffer = new StringBuilder();
 							if (this.chars == null) buffer.append(currentChar);
 							else buffer.append(this.chars);
 							break;
