@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2021 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -35,6 +35,7 @@ public static Class[] getAllTestClasses() {
 		ASTConverterBugsTestJLS3.class,
 		ASTConverterJavadocTest.class,
 		ASTConverterJavadocTest_15.class,
+		ASTConverterJavadocTest_18.class,
 		ASTConverter15Test.class,
 		ASTConverter16Test.class,
 		ASTConverter17Test.class,
@@ -56,7 +57,10 @@ public static Class[] getAllTestClasses() {
 		ASTConverter14Test.class,
 		ASTConverter_15Test.class,
 		ASTConverter_16Test.class,
+		ASTConverter_17Test.class,
+		ASTConverter_GuardedPattern_Test.class,
 		ASTConverter_PreviewTest.class,
+		ASTConverter_RecordPattern_Test.class,
 	};
 }
 public static Test suite() {
