@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2017 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -77,10 +77,12 @@ protected String getEscapedExternalJCLPath() {
 	return getEscapedPath(getExternalJCLPath().toString());
 }
 String getEscapedJrtJarPath() {
-	return getEscapedPath(System.getProperty("java.home")+"/lib/jrt-fs.jar");
+	String pathStr = System.getProperty("java.home")+"/lib/jrt-fs.jar";
+	String path = new Path(pathStr).toPortableString();
+	return getEscapedPath(path);
 }
 protected String getEscapedPath(String path) {
-	StringBuffer buffer = new StringBuffer();
+	StringBuilder buffer = new StringBuilder();
 	for (int i = 0; i < path.length(); i++) {
 		char character = path.charAt(i);
 		if (character == '/') buffer.append('\\');
@@ -875,8 +877,9 @@ public void testAnnotationPath9() throws CoreException, IOException {
 		String expectedIdentifier = "=Test/"+getEscapedJrtJarPath()+"`java.base"+attributesMemento; // for specific PFR (see below)
 		IModuleDescription module = project.findModule("java.base", null);
 		String moduleIdentifier = expectedIdentifier+"<'`java.base"; // PFR - PackageFragment - ModularClassFile - Module
-		assertEquals("Module mementos", moduleIdentifier, module.getHandleIdentifier());
-		IJavaElement module2 = JavaCore.create(module.getHandleIdentifier(), null);
+		String moduleHandleIdentifier = module.getHandleIdentifier();
+		assertEquals("Module mementos", moduleIdentifier, moduleHandleIdentifier);
+		IJavaElement module2 = JavaCore.create(moduleHandleIdentifier, null);
 		assertTrue("Module existence", module2.exists());
 		assertEquals("Module equivalence", module, module2);
 
@@ -951,4 +954,25 @@ public void testEmptyAttribute() throws CoreException, IOException {
 		deleteProject("Test");
 	}
 }
+public void testBug573147() throws CoreException, IOException {
+	try {
+		createJavaProject("Test`", new String[] {"src"}, null, "bin", "1.8", false);
+		createFile(
+				"/Test`/src/X.java",
+				"public class X<T> {\n" +
+				"  void foo() {\n" +
+				"    X<String> var = null;\n" +
+				"  }\n" +
+				"}"
+			);
+		ILocalVariable localVar = getLocalVariable(getCompilationUnit("/Test`/src/X.java"), "var", "var");
+		String memento = localVar.getHandleIdentifier();
+		IJavaElement restored = JavaCore.create(memento);
+		assertNotNull("element should not be null", restored);
+		String restoredMemento = restored.getHandleIdentifier();
+		assertEquals("Unexpected restored memento", memento, restoredMemento);
+	} finally {
+		deleteProject("Test`");
+	}
+}
 }
