@@ -139,6 +139,7 @@ public void renamePositive(IJavaElement element, String rename, boolean force) t
 /**
  * Setup for the next test.
  */
+@Override
 public void setUp() throws Exception {
 	super.setUp();
 
@@ -163,6 +164,7 @@ public void setUp() throws Exception {
 
 	startDeltas();
 }
+@Override
 public void setUpSuite() throws Exception {
 	super.setUpSuite();
 
@@ -199,12 +201,14 @@ public static Test suite() {
 /**
  * Cleanup after the previous test.
  */
+@Override
 public void tearDown() throws Exception {
 	stopDeltas();
 	this.deleteProject("P");
 
 	super.tearDown();
 }
+@Override
 public void tearDownSuite() throws Exception {
 	this.deleteProject("BinaryProject");
 	super.tearDownSuite();
@@ -368,11 +372,11 @@ public void testRenameCU2() throws CoreException {
 
 	assertDeltas(
 		"Unexpected deltas",
-		"P[*]: {CHILDREN}\n" + 
-				"	src[*]: {CHILDREN}\n" + 
-				"		<default>[*]: {CHILDREN}\n" + 
-				"			X.java[-]: {MOVED_TO(Y.java [in <default> [in src [in P]]])}\n" + 
-				"			Y.java[*]: {CHILDREN | CONTENT | FINE GRAINED | PRIMARY RESOURCE}\n" + 
+		"P[*]: {CHILDREN}\n" +
+				"	src[*]: {CHILDREN}\n" +
+				"		<default>[*]: {CHILDREN}\n" +
+				"			X.java[-]: {MOVED_TO(Y.java [in <default> [in src [in P]]])}\n" +
+				"			Y.java[*]: {CHILDREN | CONTENT | FINE GRAINED | PRIMARY RESOURCE}\n" +
 				"				Y[+]: {MOVED_FROM(X [in X.java [in <default> [in src [in P]]]])}"
 	);
 }
