@@ -17,8 +17,6 @@ import java.io.IOException;
 import java.util.HashMap;
 import java.util.Map;
 
-import junit.framework.Test;
-
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.jdt.core.Flags;
@@ -46,6 +44,8 @@ import org.eclipse.jdt.internal.core.NameLookup;
 import org.eclipse.jdt.internal.core.NameLookup.Answer;
 import org.eclipse.jdt.internal.core.SourceType;
 
+import junit.framework.Test;
+
 @SuppressWarnings({"rawtypes", "unchecked"})
 public class TypeResolveTests extends ModifyingResourceTests {
 	ICompilationUnit cu;
@@ -127,7 +127,7 @@ public void setUpSuite() throws Exception {
 }
 	static {
 //		TESTS_NUMBERS = new int[] { 182, 183 };
-//		TESTS_NAMES = new String[] { "test528818a" };
+//		TESTS_NAMES = new String[] { "testBug575503" };
 	}
 	public static Test suite() {
 		return buildModelTestSuite(TypeResolveTests.class);
@@ -1641,4 +1641,60 @@ public void testBug570314() throws Exception{
 		deleteProject("P");
 	}
 }
+public void testBug575503() throws Exception{
+	try {
+		createJava16Project("P", new String[] {"src"});
+		String source =   "package p;\n\n" +
+				"public class Ssss {\n" +
+				"	public static void main(String[] args) {\n" +
+				"		new Ssss.Entry(false, new int[0]);\n" +
+    			"	}\n" +
+    			"	record Entry(boolean isHidden, int... indexes) {\n" +
+    			"		Entry(int... indexes) {\n" +
+    			"			this(false, indexes);\n" +
+        		"		}\n" +
+    			"	}\n" +
+				"}\n";
+		createFolder("/P/src/p");
+		createFile("/P/src/p/Ssss.java", source);
+		waitForAutoBuild();
+
+		ICompilationUnit unit = getCompilationUnit("/P/src/p/Ssss.java");
+		String select = "Ssss.Entry";
+		IJavaElement[] elements = unit.codeSelect(source.indexOf(select), select.length());
+		assertEquals("should not be empty", 1, elements.length);
+		IType type = (IType) elements[0];
+		String signature= Signature.createTypeSignature(type.getFullyQualifiedName(), true);
+		assertEquals("incorrect type", "Lp.Ssss$Entry;", signature);
+	} finally {
+		deleteProject("P");
+	}
+}
+// https://bugs.eclipse.org/bugs/show_bug.cgi?id=576778
+public void testBug576778() throws Exception {
+	try {
+		createJava11Project("P", new String[] {"src"});
+		String source =    "package p;\n\n"
+				+"public class X {\n"
+				+ "  public static void main(String[] args) {\n"
+				+ "   var runnable = new Runnable() {\n"
+				+ "     public void run() {}\n"
+				+ "   };\n"
+				+ "   runnable.run();\n"
+				+ "  }\n"
+				+ "}\n";
+		createFolder("/P/src/p");
+		createFile("/P/src/p/X.java", source);
+		waitForAutoBuild();
+		ICompilationUnit unit = getCompilationUnit("/P/src/p/X.java");
+		String select = "runnable";
+		IJavaElement[] elements = unit.codeSelect(source.indexOf(select), select.length());
+		assertEquals("should not be empty", 1, elements.length);
+		ILocalVariable variable = (ILocalVariable) elements[0];
+		String signature= variable.getTypeSignature();
+		assertEquals("incorrect type", "Qvar;", signature);
+	} finally {
+		deleteProject("P");
+	}
+}
 }
