@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2021 IBM Corporation and others.
+ * Copyright (c) 2021, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -53,23 +53,23 @@ public class ASTRewritingSwitchPatternTest extends ASTRewritingTest {
 	}
 
 	public static Test suite() {
-		return createSuite(ASTRewritingSwitchPatternTest.class, 17);
+		return createSuite(ASTRewritingSwitchPatternTest.class, 19);
 	}
 
 	@Override
 	protected void setUp() throws Exception {
 		super.setUp();
-		if (this.apiLevel == AST.JLS17 ) { // Remove this after it is a standard feature
-			this.project1.setOption(JavaCore.COMPILER_COMPLIANCE, JavaCore.VERSION_17);
-			this.project1.setOption(JavaCore.COMPILER_SOURCE, JavaCore.VERSION_17);
-			this.project1.setOption(JavaCore.COMPILER_CODEGEN_TARGET_PLATFORM, JavaCore.VERSION_17);
+		if (this.apiLevel == AST.JLS19 ) { // Remove this after it is a standard feature
+			this.project1.setOption(JavaCore.COMPILER_COMPLIANCE, JavaCore.VERSION_19);
+			this.project1.setOption(JavaCore.COMPILER_SOURCE, JavaCore.VERSION_19);
+			this.project1.setOption(JavaCore.COMPILER_CODEGEN_TARGET_PLATFORM, JavaCore.VERSION_19);
 			this.project1.setOption(JavaCore.COMPILER_PB_ENABLE_PREVIEW_FEATURES, JavaCore.ENABLED);
 		}
 	}
 
 	private boolean checkAPILevel() {
-		if (this.apiLevel < 17) {
-			System.err.println("Test "+getName()+" requires a JRE 17");
+		if (this.apiLevel < 19) {
+			System.err.println("Test "+getName()+" requires a JRE 19");
 			return true;
 		}
 		return false;
@@ -342,7 +342,7 @@ public class ASTRewritingSwitchPatternTest extends ASTRewritingTest {
 		buf.append("public class X {\n");
 		buf.append(		"void foo(Object o) {\n");
 		buf.append(		"	switch (o) {\n");
-		buf.append(	    "		case Integer i && i > 10:\n");
+		buf.append(	    "		case Integer i when i > 10:\n");
 		buf.append(	    "            System.out.println(\"Greater than 10\");\n");
 		buf.append(	    "        default       	: System.out.println(\"0\");\n");
 		buf.append(	    "	}\n");
@@ -361,7 +361,7 @@ public class ASTRewritingSwitchPatternTest extends ASTRewritingTest {
 		buf.append("public class X {\n");
 		buf.append(		"void foo(Object o) {\n");
 		buf.append(		"	switch (o) {\n");
-		buf.append(	    "       case String s && s.equals(\"hi\") : System.out.println(\"hi\");\n");
+		buf.append(	    "       case String s when s.equals(\"hi\") : System.out.println(\"hi\");\n");
 		buf.append(	    "		default       	: System.out.println(\"0\");\n");
 		buf.append(	    "	}\n");
 		buf.append(	    "}\n");
@@ -410,7 +410,7 @@ public class ASTRewritingSwitchPatternTest extends ASTRewritingTest {
 		buf.append("public class X {\n");
 		buf.append(		"void foo(Object o) {\n");
 		buf.append(		"	switch (o) {\n");
-		buf.append(	    "       case Integer i && i > 10 : System.out.println(\"hi\");\n");
+		buf.append(	    "       case Integer i when i > 10 : System.out.println(\"hi\");\n");
 		buf.append(	    "		default       	: System.out.println(\"0\");\n");
 		buf.append(	    "	}\n");
 		buf.append(	    "}\n");
@@ -428,8 +428,8 @@ public class ASTRewritingSwitchPatternTest extends ASTRewritingTest {
 		buf.append("public class X {\n");
 		buf.append(		"void foo(Object o) {\n");
 		buf.append(		"	int i = switch (o) {\n");
-		buf.append(	    "		case Integer i && i > 10 : System.out.println(\"hi\");\n");
-		buf.append(	    "       case String s && s.equals(\"hi\") : System.out.println(\"hi\");\n");
+		buf.append(	    "		case Integer i when i > 10 : System.out.println(\"hi\");\n");
+		buf.append(	    "       case String s when s.equals(\"hi\") : System.out.println(\"hi\");\n");
 		buf.append(	    "		default       	-> 0;\n");
 		buf.append(	    "	};\n");
 		buf.append(	    "}\n");
@@ -468,7 +468,7 @@ public class ASTRewritingSwitchPatternTest extends ASTRewritingTest {
 		buf.append("public class X {\n");
 		buf.append(		"void foo(Object o) {\n");
 		buf.append(		"	int i = switch (o) {\n");
-		buf.append(	    "		case String s && s.equals(\"hi\") : System.out.println(\"hi\");\n");
+		buf.append(	    "		case String s when s.equals(\"hi\") : System.out.println(\"hi\");\n");
 		buf.append(	    "		default       	-> 0;\n");
 		buf.append(	    "	};\n");
 		buf.append(	    "}\n");
