@@ -43,7 +43,7 @@ public class ASTRewritingTypeAnnotationsTest extends ASTRewritingTest {
 
 	public void testCastAnnotations() throws Exception {
 		IPackageFragment pack1= this.sourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("public class X {\n");
@@ -88,7 +88,7 @@ public class ASTRewritingTypeAnnotationsTest extends ASTRewritingTest {
 			rewrite.replace((ASTNode)annotations.get(0), markerAnnotation, null);
 		}
 		String preview= evaluateRewrite(cu, rewrite);
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("public class X {\n");
@@ -107,7 +107,7 @@ public class ASTRewritingTypeAnnotationsTest extends ASTRewritingTest {
 
 	public void testWildcardTypeArgumentAnnotations() throws Exception {
 		IPackageFragment pack1= this.sourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("public class X {\n");
@@ -180,7 +180,7 @@ public class ASTRewritingTypeAnnotationsTest extends ASTRewritingTest {
 			rewrite.replace((MarkerAnnotation) wildcardType2.annotations().get(0), markerAnnotation2, null);
 		}
 		String preview= evaluateRewrite(cu, rewrite);
-		buf = new StringBuffer();
+		buf = new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("public class X {\n");
@@ -206,7 +206,7 @@ public class ASTRewritingTypeAnnotationsTest extends ASTRewritingTest {
 
 	public void testWildcardBoudAnnotation() throws Exception {
 		IPackageFragment pack1= this.sourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 
 		buf.append("public class X {\n");
 		buf.append("	public class Helper<T> {\n");
@@ -250,7 +250,7 @@ public class ASTRewritingTypeAnnotationsTest extends ASTRewritingTest {
 			rewrite.replace((MarkerAnnotation) simpleType.annotations().get(0), markerAnnotation, null);
 		}
 		String preview= evaluateRewrite(cu, rewrite);
-		buf = new StringBuffer();
+		buf = new StringBuilder();
 		buf.append("public class X {\n");
 		buf.append("	public class Helper<T> {\n");
 		buf.append("	}\n");
@@ -266,7 +266,7 @@ public class ASTRewritingTypeAnnotationsTest extends ASTRewritingTest {
 
 	public void testTypeParameterBoundAnnotations() throws Exception {
 		IPackageFragment pack1= this.sourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("\n");
@@ -310,7 +310,7 @@ public class ASTRewritingTypeAnnotationsTest extends ASTRewritingTest {
 			rewrite.replace((MarkerAnnotation) simpleType.annotations().get(0), markerAnnotation, null);
 		}
 		String preview= evaluateRewrite(cu, rewrite);
-		buf = new StringBuffer();
+		buf = new StringBuilder();
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("\n");
 		buf.append("public class X {\n");
@@ -332,7 +332,7 @@ public class ASTRewritingTypeAnnotationsTest extends ASTRewritingTest {
 
 	public void testTypeArgumentsParameterizedClassesAnnotations() throws Exception {
 		IPackageFragment pack1= this.sourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("\n");
@@ -377,7 +377,7 @@ public class ASTRewritingTypeAnnotationsTest extends ASTRewritingTest {
 			rewrite.remove((ASTNode) simpleType.annotations().get(0), null);
 		}
 		String preview= evaluateRewrite(cu, rewrite);
-		buf = new StringBuffer();
+		buf = new StringBuilder();
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("\n");
 		buf.append("public class X {\n");
@@ -398,7 +398,7 @@ public class ASTRewritingTypeAnnotationsTest extends ASTRewritingTest {
 
 	public void testTypeArgumentsMethodInvocation() throws Exception {
 		IPackageFragment pack1= this.sourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("\n");
@@ -449,7 +449,7 @@ public class ASTRewritingTypeAnnotationsTest extends ASTRewritingTest {
 			rewrite.replace((MarkerAnnotation)simpleType.annotations().get(0), markerAnnotation, null);
 		}
 		String preview= evaluateRewrite(cu, rewrite);
-		buf = new StringBuffer();
+		buf = new StringBuilder();
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("\n");
 		buf.append("public class X {\n");
@@ -478,7 +478,7 @@ public class ASTRewritingTypeAnnotationsTest extends ASTRewritingTest {
 
 	public void testClassInheritenceAnnotations() throws Exception {
 		IPackageFragment pack1= this.sourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("\n");
@@ -522,7 +522,7 @@ public class ASTRewritingTypeAnnotationsTest extends ASTRewritingTest {
 			rewrite.replace((MarkerAnnotation) simpleType.annotations().get(0), markerAnnotation, null);
 		}
 		String preview= evaluateRewrite(cu, rewrite);
-		buf = new StringBuffer();
+		buf = new StringBuilder();
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("\n");
 		buf.append("public class X {\n");
@@ -544,7 +544,7 @@ public class ASTRewritingTypeAnnotationsTest extends ASTRewritingTest {
 
 	public void testTypeTests() throws Exception {
 		IPackageFragment pack1= this.sourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("\n");
@@ -594,7 +594,7 @@ public class ASTRewritingTypeAnnotationsTest extends ASTRewritingTest {
 			rewrite.replace((MarkerAnnotation) simpleType.annotations().get(0), markerAnnotation, null);
 		}
 		String preview= evaluateRewrite(cu, rewrite);
-		buf = new StringBuffer();
+		buf = new StringBuilder();
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("\n");
 		buf.append("public class X {\n");
@@ -619,7 +619,7 @@ public class ASTRewritingTypeAnnotationsTest extends ASTRewritingTest {
 
 	public void testConstructorInvocation() throws Exception {
 		IPackageFragment pack1= this.sourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append(" \n");
 		buf.append("public class X {\n");
@@ -666,7 +666,7 @@ public class ASTRewritingTypeAnnotationsTest extends ASTRewritingTest {
 			rewrite.replace((MarkerAnnotation) simpleType.annotations().get(0), markerAnnotation, null);
 		}
 		String preview= evaluateRewrite(cu, rewrite);
-		buf = new StringBuffer();
+		buf = new StringBuilder();
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append(" \n");
 		buf.append("public class X {\n");
@@ -688,7 +688,7 @@ public class ASTRewritingTypeAnnotationsTest extends ASTRewritingTest {
 
 	public void testConstructorDeclaration() throws Exception {
 		IPackageFragment pack1= this.sourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("\n");
 		buf.append("public class X {\n");
@@ -725,7 +725,7 @@ public class ASTRewritingTypeAnnotationsTest extends ASTRewritingTest {
 			rewrite.replace((MarkerAnnotation) methodDeclaration.modifiers().get(0), markerAnnotation, null);
 		}
 		String preview= evaluateRewrite(cu, rewrite);
-		buf = new StringBuffer();
+		buf = new StringBuilder();
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("\n");
 		buf.append("public class X {\n");
@@ -746,7 +746,7 @@ public class ASTRewritingTypeAnnotationsTest extends ASTRewritingTest {
 
 	public void testRewriteInsertAPIAnnotation() throws Exception {
 		IPackageFragment pack1= this.sourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("\n");
@@ -796,7 +796,7 @@ public class ASTRewritingTypeAnnotationsTest extends ASTRewritingTest {
 			rewrite.getListRewrite(simpleType, SimpleType.ANNOTATIONS_PROPERTY).insertBefore(markerAnnotation, (MarkerAnnotation) simpleType.annotations().get(1), null);
 		}
 		String preview= evaluateRewrite(cu, rewrite);
-		buf = new StringBuffer();
+		buf = new StringBuilder();
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("\n");
 		buf.append("public class X {\n");
@@ -817,7 +817,7 @@ public class ASTRewritingTypeAnnotationsTest extends ASTRewritingTest {
 
 	public void testEmptyListInsertAnnotation() throws Exception {
 		IPackageFragment pack1= this.sourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class X {\n");
 		buf.append("	String myObject = \"Foo\";\n");
@@ -843,7 +843,7 @@ public class ASTRewritingTypeAnnotationsTest extends ASTRewritingTest {
 			rewrite.getListRewrite(simpleType, SimpleType.ANNOTATIONS_PROPERTY).insertLast(markerAnnotation, null);
 		}
 		String preview= evaluateRewrite(cu, rewrite);
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class X {\n");
 		buf.append("	String myObject = \"Foo\";\n");
@@ -897,7 +897,7 @@ public class ASTRewritingTypeAnnotationsTest extends ASTRewritingTest {
 				"class FileNotFoundException extends Exception{private static final long serialVersionUID=10002L;}\n" +
 				"class EOFException extends Exception{private static final long serialVersionUID=10003L;}\n" +
 				"class IOError extends Exception{private static final long serialVersionUID=10004L;}\n";
-		StringBuffer buf = new StringBuffer(contents);
+		StringBuilder buf = new StringBuilder(contents);
 		ICompilationUnit cu= pack1.createCompilationUnit("X.java", buf.toString(), false, null);
 		CompilationUnit astRoot= createAST(cu, /* resolve */ true, false);
 		ASTRewrite rewrite= ASTRewrite.create(astRoot.getAST());
@@ -1008,7 +1008,7 @@ public class ASTRewritingTypeAnnotationsTest extends ASTRewritingTest {
 				 "@Target (java.lang.annotation.ElementType.TYPE_USE)\n" +
 				 "@interface Marker2 {}\n";
 
-		StringBuffer buf = new StringBuffer(contents);
+		StringBuilder buf = new StringBuilder(contents);
 		ICompilationUnit cu= pack1.createCompilationUnit("X.java", buf.toString(), false, null);
 		CompilationUnit astRoot= createAST(cu, /* resolve */ true, false);
 		ASTRewrite rewrite= ASTRewrite.create(astRoot.getAST());
