@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2014, 2016 IBM Corporation and others.
+ * Copyright (c) 2014, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -71,6 +71,7 @@ public class ImportRewrite18Test extends AbstractJavaModelTests {
 		return allTests();
 	}
 
+	@Override
 	protected void setUp() throws Exception {
 		super.setUp();
 
@@ -96,6 +97,7 @@ public class ImportRewrite18Test extends AbstractJavaModelTests {
 	protected static int getJLS8() {
 		return AST.JLS8;
 	}
+	@Override
 	protected void tearDown() throws Exception {
 		deleteProject(PROJECT);
 		super.tearDown();
@@ -187,7 +189,7 @@ public class ImportRewrite18Test extends AbstractJavaModelTests {
 		parser.setSource(cu);
 		parser.setResolveBindings(true);
 		parser.setStatementsRecovery(true);
-		astRoot = (CompilationUnit) parser.createAST(null);	
+		astRoot = (CompilationUnit) parser.createAST(null);
 		TypeDeclaration type= (TypeDeclaration) astRoot.types().get(0);
 		MethodDeclaration [] methods =  type.getMethods();
 		MethodDeclaration method = methods[0];
@@ -244,7 +246,7 @@ public class ImportRewrite18Test extends AbstractJavaModelTests {
 		parser.setSource(cu);
 		parser.setResolveBindings(true);
 		parser.setStatementsRecovery(true);
-		astRoot = (CompilationUnit) parser.createAST(null);	
+		astRoot = (CompilationUnit) parser.createAST(null);
 		TypeDeclaration type= (TypeDeclaration) astRoot.types().get(0);
 		MethodDeclaration [] methods =  type.getMethods();
 		MethodDeclaration method = methods[0];
@@ -395,7 +397,7 @@ public class ImportRewrite18Test extends AbstractJavaModelTests {
 				"			\n" +
 				"		}\n" +
 				"	}\n" +
-				"}\n" + 
+				"}\n" +
 		createFolder("/" + PROJECT + "/src/pack3");
 		createFile("/" + PROJECT + "/src/pack3/C1.java", contents);
 		contents = "package pack4;\n" +
@@ -414,7 +416,7 @@ public class ImportRewrite18Test extends AbstractJavaModelTests {
 		parser.setSource(cu);
 		parser.setResolveBindings(true);
 		parser.setStatementsRecovery(true);
-		CompilationUnit astRoot = (CompilationUnit) parser.createAST(null);	
+		CompilationUnit astRoot = (CompilationUnit) parser.createAST(null);
 		TypeDeclaration typeDeclaration = (TypeDeclaration) astRoot.types().get(0);
 		MethodDeclaration [] methods =  typeDeclaration.getMethods();
 		MethodDeclaration method = methods[0];
@@ -476,7 +478,7 @@ public class ImportRewrite18Test extends AbstractJavaModelTests {
 				"			\n" +
 				"		}\n" +
 				"	}\n" +
-				"}\n" + 
+				"}\n" +
 		createFolder("/" + PROJECT + "/src/pack4");
 		createFile("/" + PROJECT + "/src/pack4/D1.java", contents);
 
@@ -607,7 +609,7 @@ public class ImportRewrite18Test extends AbstractJavaModelTests {
 		if(testNullImportRewriteContext) {
 			actualType = rewrite.addImport(typeBinding, astRoot.getAST(), null, TypeLocation.UNKNOWN);
 		} else {
-			actualType = rewrite.addImport(typeBinding, astRoot.getAST());			
+			actualType = rewrite.addImport(typeBinding, astRoot.getAST());
 		}
 		return actualType;
 	}
@@ -770,7 +772,7 @@ public class ImportRewrite18Test extends AbstractJavaModelTests {
 	}
 
 	public void testBug474270_since_8() throws Exception {
-		String contents = 
+		String contents =
 				"package pack1;\n" +
 				"import java.util.Comparator;\n" +
 				"interface Comparator<T> {\n" +
@@ -792,7 +794,7 @@ public class ImportRewrite18Test extends AbstractJavaModelTests {
 		parser.setSource(cu);
 		parser.setResolveBindings(true);
 		parser.setStatementsRecovery(true);
-		CompilationUnit astRoot = (CompilationUnit) parser.createAST(null);	
+		CompilationUnit astRoot = (CompilationUnit) parser.createAST(null);
 		TypeDeclaration type= (TypeDeclaration) astRoot.types().get(1);
 		MethodDeclaration [] methods =  type.getMethods();
 		MethodDeclaration method = methods[0];
@@ -840,9 +842,48 @@ public class ImportRewrite18Test extends AbstractJavaModelTests {
 		edit.apply(document);
 		compilationUnit.getBuffer().setContents(document.get());
 	}
-	
+
 	public void testBug513869() throws Exception {
 		Type actualType = runTest426094andGetType(0, true);
 		assertEquals(this.bug426094TestInput[0][1], actualType.toString());
 	}
+
+	/*
+	 * Import should not be added in the default package
+	 */
+	public void testBug563375() throws Exception {
+		String contents = ""+
+				"public class X {\n" +
+				"	public static void main(String[] args) {\n" +
+				"		var i_S = i_s();\n" +
+				"		System.out.println(i_S.toString());\n" +
+				"		}\n" +
+				"	\n" +
+				"	static class I_S {}\n" +
+				"	\n" +
+				"	private static I_S i_s() {\n" +
+				"		return new I_S();\n" +
+				"	}\n" +
+				"}";
+		createFile("/" + PROJECT + "/src/X.java", contents);
+
+		ICompilationUnit cu= getCompilationUnit("/" + PROJECT + "/src/X.java");
+		ASTParser parser = ASTParser.newParser(getJLS8());
+		parser.setSource(cu);
+		parser.setResolveBindings(true);
+		parser.setStatementsRecovery(true);
+		CompilationUnit astRoot = (CompilationUnit) parser.createAST(null);
+
+		TypeDeclaration clazz= (TypeDeclaration) astRoot.types().get(0);
+		ITypeBinding binding= clazz.resolveBinding();
+		ITypeBinding iBinding= binding.getDeclaredTypes()[0];
+		assertNotNull(iBinding);
+		ImportRewrite rewrite = newImportsRewrite(cu, new String[0], 99, 99, true);
+		cu = getCompilationUnit("/" + PROJECT + "/src/X.java");
+		rewrite = newImportsRewrite(cu, new String[0], 99, 99, true);
+		String actualType = rewrite.addImport(iBinding);
+		assertEquals("X.I_S", actualType);
+		apply(rewrite);
+		assertEquals(0, cu.getImports().length);
+	}
 }
