@@ -20,6 +20,8 @@ public class C {
 		case "abc1" -> System.out.println("1");
 		case "abc2",
 		/* ??? */   "abc3", "abc4" -> System.out.println("234");
+		case "def2", /* ??? */
+		   "def3", "def4" -> System.out.println("def");
 		case "abc5", "abc6" -> {}
 		case "abc7" -> {
 			System.out.println("7");
