@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2019, 2020 IBM Corporation.
+ * Copyright (c) 2019, 2022 IBM Corporation.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -7,15 +7,13 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
+ *     Christoph Läubrich - use Filesystem helper method
  *******************************************************************************/
 package org.eclipse.jdt.internal.compiler.batch;
 
 import java.io.File;
 import java.io.IOException;
-import java.net.URI;
 import java.nio.file.DirectoryStream;
-import java.nio.file.FileSystemNotFoundException;
-import java.nio.file.FileSystems;
 import java.nio.file.FileVisitResult;
 import java.nio.file.FileVisitor;
 import java.nio.file.Files;
@@ -38,6 +36,7 @@ import org.eclipse.jdt.internal.compiler.classfmt.ClassFormatException;
 import org.eclipse.jdt.internal.compiler.env.AccessRuleSet;
 import org.eclipse.jdt.internal.compiler.env.IModule;
 import org.eclipse.jdt.internal.compiler.env.NameEnvironmentAnswer;
+import org.eclipse.jdt.internal.compiler.util.CtSym;
 import org.eclipse.jdt.internal.compiler.util.JRTUtil;
 import org.eclipse.jdt.internal.compiler.util.Util;
 
@@ -65,6 +64,7 @@ public class ClasspathJep247Jdk12 extends ClasspathJep247 {
 		try {
 			ClassFileReader reader = null;
 			byte[] content = null;
+			char[] foundModName = null;
 			qualifiedBinaryFileName = qualifiedBinaryFileName.replace(".class", ".sig"); //$NON-NLS-1$ //$NON-NLS-2$
 			if (this.subReleases != null && this.subReleases.length > 0) {
 				done: for (String rel : this.subReleases) {
@@ -75,6 +75,7 @@ public class ClasspathJep247Jdk12 extends ClasspathJep247 {
 								Path f = this.fs.getPath(rel, JRTUtil.sanitizedFileName(subdir), qualifiedBinaryFileName);
 								if (Files.exists(f)) {
 									content = JRTUtil.safeReadBytes(f);
+									foundModName = JRTUtil.sanitizedFileName(subdir).toCharArray();
 									if (content != null)
 										break done;
 								}
@@ -94,7 +95,7 @@ public class ClasspathJep247Jdk12 extends ClasspathJep247 {
 			}
 			if (content != null) {
 				reader = new ClassFileReader(content, qualifiedBinaryFileName.toCharArray());
-				char[] modName = moduleName != null ? moduleName.toCharArray() : null;
+				char[] modName = moduleName != null ? moduleName.toCharArray() : foundModName;
 				return new NameEnvironmentAnswer(reader, fetchAccessRestriction(qualifiedBinaryFileName), modName);
 			}
 		} catch (ClassFormatException | IOException e) {
@@ -112,22 +113,12 @@ public class ClasspathJep247Jdk12 extends ClasspathJep247 {
 			super.initialize();
 			return;
 		}
-		this.releaseInHex = Integer.toHexString(Integer.parseInt(this.compliance)).toUpperCase();
+		this.releaseInHex = CtSym.getReleaseCode(this.compliance);
 		Path filePath = this.jdkHome.toPath().resolve("lib").resolve("ct.sym"); //$NON-NLS-1$ //$NON-NLS-2$
-		URI t = filePath.toUri();
 		if (!Files.exists(filePath)) {
 			return;
 		}
-		URI uri = URI.create("jar:file:" + t.getRawPath()); //$NON-NLS-1$
-		try {
-			this.fs = FileSystems.getFileSystem(uri);
-		} catch(FileSystemNotFoundException fne) {
-			// Ignore and move on
-		}
-		if (this.fs == null) {
-			HashMap<String, ?> env = new HashMap<>();
-			this.fs = FileSystems.newFileSystem(uri, env);
-		}
+		this.fs = JRTUtil.getJarFileSystem(filePath);
 		this.releasePath = this.fs.getPath("/"); //$NON-NLS-1$
 		if (!Files.exists(this.fs.getPath(this.releaseInHex))) {
 			throw new IllegalArgumentException("release " + this.compliance + " is not found in the system");  //$NON-NLS-1$//$NON-NLS-2$
@@ -141,29 +132,34 @@ public class ClasspathJep247Jdk12 extends ClasspathJep247 {
 			}
 			this.subReleases = sub.toArray(new String[sub.size()]);
 		} catch (IOException e) {
-			//e.printStackTrace();
+			String error = "Failed to walk subreleases for release " + this.releasePath + " in " + filePath; //$NON-NLS-1$ //$NON-NLS-2$
+			if (JRTUtil.PROPAGATE_IO_ERRORS) {
+				throw new IllegalStateException(error, e);
+			} else {
+				System.err.println(error);
+				e.printStackTrace();
+			}
 		}
 		super.initialize();
 	}
 	@Override
 	public void loadModules() {
-		// Modules below level 8 are not dealt with here. Leave it to ClasspathJrt
+		// Modules below level 9 are not dealt with here. Leave it to ClasspathJrt
 		if (this.jdklevel <= ClassFileConstants.JDK1_8) {
 			super.loadModules();
 			return;
 		}
 		final Path modPath = this.fs.getPath(this.releaseInHex);
 		this.modulePath = this.file.getPath() + "|" + modPath.toString(); //$NON-NLS-1$
-		this.modules = ModulesCache.get(this.modulePath);
-		if (this.modules == null) {
+		Map<String, IModule> cache = ModulesCache.computeIfAbsent(this.modulePath, key -> {
+			HashMap<String,IModule> newCache = new HashMap<>();
 			try (DirectoryStream<java.nio.file.Path> stream = Files.newDirectoryStream(this.releasePath)) {
-				HashMap<String,IModule> newCache = new HashMap<>();
 				for (final java.nio.file.Path subdir: stream) {
 					String rel = JRTUtil.sanitizedFileName(subdir);
 					if (!rel.contains(this.releaseInHex)) {
 						continue;
 					}
-					Files.walkFileTree(subdir, Collections.EMPTY_SET, 2, new FileVisitor<java.nio.file.Path>() {
+					Files.walkFileTree(subdir, Collections.emptySet(), 2, new FileVisitor<java.nio.file.Path>() {
 
 						@Override
 						public FileVisitResult preVisitDirectory(java.nio.file.Path dir, BasicFileAttributes attrs)
@@ -173,16 +169,17 @@ public class ClasspathJep247Jdk12 extends ClasspathJep247 {
 
 						@Override
 						public FileVisitResult visitFile(java.nio.file.Path f, BasicFileAttributes attrs) throws IOException {
-							if (attrs.isDirectory() || f.getNameCount() < 3)
+							if (attrs.isDirectory() || f.getNameCount() < 3) {
 								return FileVisitResult.CONTINUE;
+							}
 							if (f.getFileName().toString().equals(MODULE_INFO) && Files.exists(f)) {
 								byte[] content = JRTUtil.safeReadBytes(f);
-								if (content == null)
+								if (content == null) {
 									return FileVisitResult.CONTINUE;
+								}
 								Path m = f.subpath(1, f.getNameCount() - 1);
 								String name = JRTUtil.sanitizedFileName(m);
 								ClasspathJep247Jdk12.this.acceptModule(name, content, newCache);
-								ClasspathJep247Jdk12.this.moduleNamesCache.add(name);
 							}
 							return FileVisitResult.SKIP_SIBLINGS;
 						}
@@ -198,18 +195,20 @@ public class ClasspathJep247Jdk12 extends ClasspathJep247 {
 						}
 					});
 				}
-				synchronized(ModulesCache) {
-					if (ModulesCache.get(this.modulePath) == null) {
-						this.modules = Collections.unmodifiableMap(newCache);
-						ModulesCache.put(this.modulePath, this.modules);
-					}
-				}
 			} catch (IOException e) {
-				e.printStackTrace();
+				String error = "Failed to walk modules for " + key; //$NON-NLS-1$
+				if (JRTUtil.PROPAGATE_IO_ERRORS) {
+					throw new IllegalStateException(error, e);
+				} else {
+					System.err.println(error);
+					e.printStackTrace();
+					return null;
+				}
 			}
-		} else {
-			this.moduleNamesCache.addAll(this.modules.keySet());
-		}
+			return newCache.isEmpty() ? null : Collections.unmodifiableMap(newCache);
+		});
+		this.modules = cache;
+		this.moduleNamesCache.addAll(cache.keySet());
 	}
 	@Override
 	public Collection<String> getModuleNames(Collection<String> limitModule, Function<String, IModule> getModule) {
@@ -217,6 +216,10 @@ public class ClasspathJep247Jdk12 extends ClasspathJep247 {
 	}
 	@Override
 	public IModule getModule(char[] moduleName) {
+		// Modules below level 9 are not dealt with here. Leave it to ClasspathJrt
+		if (this.jdklevel <= ClassFileConstants.JDK1_8) {
+			return super.getModule(moduleName);
+		}
 		if (this.modules != null) {
 			return this.modules.get(String.valueOf(moduleName));
 		}
@@ -241,7 +244,7 @@ public class ClasspathJep247Jdk12 extends ClasspathJep247 {
 	}
 	@Override
 	void acceptModule(ClassFileReader reader, Map<String, IModule> cache) {
-		// Modules below level 8 are not dealt with here. Leave it to ClasspathJrt
+		// Modules below level 9 are not dealt with here. Leave it to ClasspathJrt
 		if (this.jdklevel <= ClassFileConstants.JDK1_8) {
 			super.acceptModule(reader, cache);
 			return;
@@ -255,6 +258,11 @@ public class ClasspathJep247Jdk12 extends ClasspathJep247 {
 	}
 	@Override
 	public synchronized char[][] getModulesDeclaringPackage(String qualifiedPackageName, String moduleName) {
+		if (this.jdklevel >= ClassFileConstants.JDK9) {
+			// Delegate to the boss, even if it means inaccurate error reporting at times
+			List<String> mods = JRTUtil.getModulesDeclaringPackage(this.file, qualifiedPackageName, moduleName);
+			return CharOperation.toCharArrays(mods);
+		}
 		if (this.packageCache == null) {
 			this.packageCache = new HashSet<>(41);
 			this.packageCache.add(Util.EMPTY_STRING);
@@ -295,15 +303,16 @@ public class ClasspathJep247Jdk12 extends ClasspathJep247 {
 					}
 				}
 			} catch (IOException e) {
-				e.printStackTrace();
-				// Rethrow
+				String error = "Failed to find module " + moduleName + " defining package " + qualifiedPackageName //$NON-NLS-1$ //$NON-NLS-2$
+						+ " in release " + this.releasePath + " in " + this; //$NON-NLS-1$ //$NON-NLS-2$
+				if (JRTUtil.PROPAGATE_IO_ERRORS) {
+					throw new IllegalStateException(error, e);
+				} else {
+					System.err.println(error);
+					e.printStackTrace();
+				}
 			}
 		}
-		if (moduleName == null) {
-			// Delegate to the boss, even if it means inaccurate error reporting at times
-			List<String> mods = JRTUtil.getModulesDeclaringPackage(this.file, qualifiedPackageName, moduleName);
-			return CharOperation.toCharArrays(mods);
-		}
 		return singletonModuleNameIf(this.packageCache.contains(qualifiedPackageName));
 	}
 }
