@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -127,6 +127,7 @@ public class FileSystem implements IModuleAwareNameEnvironment, SuffixConstants
 		public String getDestinationPath();
 		Collection<String> getModuleNames(Collection<String> limitModules);
 		Collection<String> getModuleNames(Collection<String> limitModules, Function<String,IModule> getModule);
+		default boolean forbidsExportFrom(String modName) { return false; }
 	}
 	public interface ClasspathSectionProblemReporter {
 		void invalidClasspathSection(String jarFilePath);
@@ -188,22 +189,34 @@ public class FileSystem implements IModuleAwareNameEnvironment, SuffixConstants
 	initialFileNames is a collection is Strings, the trailing '.java' will be removed if its not already.
 */
 public FileSystem(String[] classpathNames, String[] initialFileNames, String encoding) {
-	this(classpathNames, initialFileNames, encoding, null);
+	this(classpathNames, initialFileNames, encoding, null, null);
+}
+public FileSystem(String[] classpathNames, String[] initialFileNames, String encoding, String release) {
+	this(classpathNames, initialFileNames, encoding, null, release);
 }
 protected FileSystem(String[] classpathNames, String[] initialFileNames, String encoding, Collection<String> limitModules) {
+	this(classpathNames,initialFileNames, encoding, limitModules, null);
+}
+protected FileSystem(String[] classpathNames, String[] initialFileNames, String encoding, Collection<String> limitModules, String release) {
 	final int classpathSize = classpathNames.length;
 	this.classpaths = new Classpath[classpathSize];
 	int counter = 0;
 	this.hasLimitModules = limitModules != null && !limitModules.isEmpty();
 	for (int i = 0; i < classpathSize; i++) {
-		Classpath classpath = getClasspath(classpathNames[i], encoding, null, null, null);
+		Classpath classpath = getClasspath(classpathNames[i], encoding, null, null, release);
 		try {
 			classpath.initialize();
 			for (String moduleName : classpath.getModuleNames(limitModules))
 				this.moduleLocations.put(moduleName, classpath);
 			this.classpaths[counter++] = classpath;
 		} catch (IOException e) {
-			// ignore
+			String error = "Failed to init " + classpath; //$NON-NLS-1$
+			if (JRTUtil.PROPAGATE_IO_ERRORS) {
+				throw new IllegalStateException(error, e);
+			} else {
+				System.err.println(error);
+				e.printStackTrace();
+			}
 		}
 	}
 	if (counter != classpathSize) {
@@ -223,9 +236,17 @@ protected FileSystem(Classpath[] paths, String[] initialFileNames, boolean annot
 			for (String moduleName : classpath.getModuleNames(limitedModules))
 				this.moduleLocations.put(moduleName, classpath);
 			this.classpaths[counter++] = classpath;
-		} catch(IOException | InvalidPathException exception) {
+		} catch(InvalidPathException exception) {
 			// JRE 9 could throw an IAE if the linked JAR paths have invalid chars, such as ":"
 			// ignore
+		} catch (IOException e) {
+			String error = "Failed to init " + classpath; //$NON-NLS-1$
+			if (JRTUtil.PROPAGATE_IO_ERRORS) {
+				throw new IllegalStateException(error, e);
+			} else {
+				System.err.println(error);
+				e.printStackTrace();
+			}
 		}
 	}
 	if (counter != length) {
