@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2020 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -31,9 +31,13 @@ import org.eclipse.jdt.internal.compiler.parser.TerminalTokens;
 @SuppressWarnings({"rawtypes", "unchecked"})
 public class CompletionJavadocParser extends JavadocParser {
 
+	boolean parsingSnippet=false;
+
 	// Initialize lengthes for block and inline tags tables
 	public final static int INLINE_ALL_TAGS_LENGTH;
 	public final static int BLOCK_ALL_TAGS_LENGTH;
+	public final static int SNIPPET_ALL_TAGS_LENGTH;
+
 	static {
 		int length = 0;
 		for (int i=0; i<INLINE_TAGS_LENGTH; i++) {
@@ -45,11 +49,17 @@ public class CompletionJavadocParser extends JavadocParser {
 			length += BLOCK_TAGS[i].length;
 		}
 		BLOCK_ALL_TAGS_LENGTH = length;
+		length = 0;
+		for (int i=0; i<SNIPPET_TAGS_LENGTH; i++) {
+			length += IN_SNIPPET_TAGS[i].length;
+		}
+		SNIPPET_ALL_TAGS_LENGTH = length;
+		//IN_SNIPPET_TAGS
 	}
 
 	// Level tags are array of inline/block tags depending on compilation source level
-	char[][][] levelTags = new char[2][][];
-	int[] levelTagsLength = new int[2];
+	char[][][] levelTags = new char[3][][];
+	int[] levelTagsLength = new int[3];
 
 	// Completion specific info
 	int cursorLocation;
@@ -62,6 +72,7 @@ public class CompletionJavadocParser extends JavadocParser {
 		this.scanner = new CompletionScanner(ClassFileConstants.JDK1_3);
 		this.kind = COMPLETION_PARSER | TEXT_PARSE;
 		initLevelTags();
+		setSourceComplianceLevel();
 	}
 
 	/*
@@ -198,7 +209,7 @@ public class CompletionJavadocParser extends JavadocParser {
 	 * Create type reference. If it includes completion location, create and store completion node.
 	 */
 	@Override
-	protected Object createTypeReference(int primitiveToken) {
+	protected Object createTypeReference(int primitiveToken, boolean canBeModule) {
 		// Need to create type ref in case it was needed by members
 		int nbIdentifiers = this.identifierLengthStack[this.identifierLengthPtr];
 		int startPtr = this.identifierPtr - (nbIdentifiers-1);
@@ -207,7 +218,7 @@ public class CompletionJavadocParser extends JavadocParser {
 		boolean inCompletion = (refStart <= (this.cursorLocation+1) && this.cursorLocation <= refEnd) // completion cursor is between first and last stacked identifiers
 			|| ((refStart == (refEnd+1) && refEnd == this.cursorLocation)); // or it's a completion on empty token
 		if (!inCompletion) {
-			return super.createTypeReference(primitiveToken);
+			return super.createTypeReference(primitiveToken, canBeModule);
 		}
 		this.identifierLengthPtr--;
 		if (nbIdentifiers == 1) { // Single Type ref
@@ -252,17 +263,102 @@ public class CompletionJavadocParser extends JavadocParser {
 		return this.completionNode;
 	}
 
+	@Override
+	protected Object createModuleTypeReference(int primitiveToken, int moduleRefTokenCount) {
+
+		// Need to create type ref in case it was needed by members
+		int nbIdentifiers = this.identifierLengthStack[this.identifierLengthPtr];
+		int startPtr = this.identifierPtr - (nbIdentifiers-1);
+		int refStart = (int) (this.identifierPositionStack[startPtr] >>> 32);
+		int refEnd = (int) this.identifierPositionStack[this.identifierPtr];
+		boolean inCompletion = (refStart <= (this.cursorLocation+1) && this.cursorLocation <= refEnd) // completion cursor is between first and last stacked identifiers
+			|| ((refStart == (refEnd+1) && refEnd == this.cursorLocation)); // or it's a completion on empty token
+		if (!inCompletion) {
+			return super.createModuleTypeReference(primitiveToken, moduleRefTokenCount);
+		}
+
+		JavadocModuleReference moduleRef= createModuleReference(moduleRefTokenCount);
+
+		TypeReference typeRef = null;
+		int size = this.identifierLengthStack[this.identifierLengthPtr];
+		int newSize= size-moduleRefTokenCount;
+		if (newSize == 1) { // Single Type ref
+			typeRef = new CompletionOnJavadocSingleTypeReference(
+					this.identifierStack[moduleRefTokenCount],
+					this.identifierPositionStack[moduleRefTokenCount],
+					this.tagSourceStart,
+					this.tagSourceEnd);
+		} else if (newSize > 1) { // Qualified Type ref
+			for (int i=moduleRefTokenCount+1; i<this.identifierPtr; i++) {
+				int start = (int) (this.identifierPositionStack[i] >>> 32);
+				int end = (int) this.identifierPositionStack[i];
+				if (start <= this.cursorLocation && this.cursorLocation <= end) {
+					if (i == moduleRefTokenCount) {
+						this.completionNode = new CompletionOnJavadocSingleTypeReference(
+									this.identifierStack[moduleRefTokenCount+1],
+									this.identifierPositionStack[moduleRefTokenCount+1],
+									this.tagSourceStart,
+									this.tagSourceEnd);
+					} else {
+						char[][] tokens = new char[i][];
+						System.arraycopy(this.identifierStack, moduleRefTokenCount, tokens, 0, i);
+						long[] positions = new long[i+1];
+						System.arraycopy(this.identifierPositionStack, moduleRefTokenCount, positions, 0, i+1);
+						typeRef = new CompletionOnJavadocQualifiedTypeReference(tokens, this.identifierStack[i], positions, this.tagSourceStart, this.tagSourceEnd);
+					}
+					break;
+				}
+			}
+			if (this.completionNode == null) {
+				char[][] tokens = new char[newSize-1][];
+				System.arraycopy(this.identifierStack, moduleRefTokenCount, tokens, 0, newSize-1);
+				long[] positions = new long[newSize];
+				System.arraycopy(this.identifierPositionStack, moduleRefTokenCount, positions, 0, newSize);
+				typeRef = new CompletionOnJavadocQualifiedTypeReference(tokens, this.identifierStack[this.identifierPtr], positions, this.tagSourceStart, this.tagSourceEnd);
+			}
+
+		}
+
+		moduleRef.setTypeReference(typeRef);
+		this.completionNode = (CompletionOnJavadocModuleReference)moduleRef;
+		return moduleRef;
+	}
+
+	@Override
+	protected JavadocModuleReference createModuleReference(int moduleRefTokenCount) {
+		JavadocModuleReference moduleRef = null;
+		char[][] tokens = new char[moduleRefTokenCount][];
+		System.arraycopy(this.identifierStack, 0, tokens, 0, moduleRefTokenCount);
+		long[] positions = new long[moduleRefTokenCount+1];
+		System.arraycopy(this.identifierPositionStack, 0, positions, 0, moduleRefTokenCount+1);
+		moduleRef = new CompletionOnJavadocModuleReference(tokens, this.identifierStack[this.identifierPtr], positions, this.tagSourceStart, this.tagSourceEnd);
+		return moduleRef;
+	}
+
 	/*
 	 * Get possible tags for a given prefix.
 	 */
-	private char[][][] possibleTags(char[] prefix, boolean newLine) {
-		char[][][] possibleTags = new char[2][][];
-		if (newLine) {
+	private char[][][] possibleTags(char[] prefix, boolean newLine, boolean inSnippet) {
+		char[][][] possibleTags = new char[3][][];
+		if (newLine && inSnippet == false) {
 			System.arraycopy(this.levelTags[BLOCK_IDX], 0, possibleTags[BLOCK_IDX] = new char[this.levelTagsLength[BLOCK_IDX]][], 0, this.levelTagsLength[BLOCK_IDX]);
 		} else {
 			possibleTags[BLOCK_IDX] = CharOperation.NO_CHAR_CHAR;
 		}
-		System.arraycopy(this.levelTags[INLINE_IDX], 0, possibleTags[INLINE_IDX] = new char[this.levelTagsLength[INLINE_IDX]][], 0, this.levelTagsLength[INLINE_IDX]);
+		if(inSnippet==false) {
+			System.arraycopy(this.levelTags[INLINE_IDX], 0, possibleTags[INLINE_IDX] = new char[this.levelTagsLength[INLINE_IDX]][], 0, this.levelTagsLength[INLINE_IDX]);
+		}
+		else {
+			possibleTags[INLINE_IDX] = CharOperation.NO_CHAR_CHAR;
+		}
+
+		if(inSnippet) {
+			System.arraycopy(this.levelTags[SNIPPET_IDX], 0, possibleTags[SNIPPET_IDX] = new char[this.levelTagsLength[SNIPPET_IDX]][], 0, this.levelTagsLength[SNIPPET_IDX]);
+
+		}
+		else {
+			possibleTags[SNIPPET_IDX] = CharOperation.NO_CHAR_CHAR;
+		}
 		if (prefix == null || prefix.length == 0) return possibleTags;
 		int kinds = this.levelTags.length;
 		for (int k=0; k<kinds; k++) {
@@ -319,15 +415,30 @@ public class CompletionJavadocParser extends JavadocParser {
 		if (this.levelTagsLength[INLINE_IDX] < INLINE_ALL_TAGS_LENGTH) {
 			System.arraycopy(this.levelTags[INLINE_IDX], 0, this.levelTags[INLINE_IDX] = new char[this.levelTagsLength[INLINE_IDX]][], 0, this.levelTagsLength[INLINE_IDX]);
 		}
+		// Init inline tags
+		this.levelTags[SNIPPET_IDX] = new char[SNIPPET_ALL_TAGS_LENGTH][];
+		this.levelTagsLength[SNIPPET_IDX]= 0;
+		for (int i=0; i< 1; i++) {// since only in java 18
+			int length = IN_SNIPPET_TAGS[i].length;
+			System.arraycopy(IN_SNIPPET_TAGS[i], 0, this.levelTags[SNIPPET_IDX], this.levelTagsLength[SNIPPET_IDX], length);
+			this.levelTagsLength[SNIPPET_IDX] += length;
+		}
+		if (this.levelTagsLength[SNIPPET_IDX] < INLINE_ALL_TAGS_LENGTH) {
+			System.arraycopy(this.levelTags[SNIPPET_IDX], 0, this.levelTags[SNIPPET_IDX] = new char[this.levelTagsLength[SNIPPET_IDX]][], 0, this.levelTagsLength[SNIPPET_IDX]);
+		}
+	}
+	@Override
+	protected Object parseArguments(Object receiver) throws InvalidInputException {
+		return parseArguments(receiver, true);
 	}
 	/*
 	 * Parse argument in @see tag method reference
 	 */
 	@Override
-	protected Object parseArguments(Object receiver) throws InvalidInputException {
+	protected Object parseArguments(Object receiver, boolean verifySpaceOrEndComment) throws InvalidInputException {
 
 		if (this.tagSourceStart>this.cursorLocation) {
-			return super.parseArguments(receiver);
+			return super.parseArguments(receiver, verifySpaceOrEndComment);
 		}
 
 		// Init
@@ -341,133 +452,140 @@ public class CompletionJavadocParser extends JavadocParser {
 		long[] dimPositions = new long[20]; // assume that there won't be more than 20 dimensions...
 		char[] name = null;
 		long argNamePos = -1;
+		boolean tokenWhiteSpace = this.scanner.tokenizeWhiteSpace;
+		this.scanner.tokenizeWhiteSpace = false;
 
-		// Parse arguments declaration if method reference
-		nextArg : while (this.index < this.scanner.eofPosition) {
+		try {
+			// Parse arguments declaration if method reference
+			nextArg : while (this.index < this.scanner.eofPosition) {
 
-			// Read argument type reference
-			try {
-				typeRef = parseQualifiedName(false);
-				if (this.abort) return null; // May be aborted by specialized parser
-			} catch (InvalidInputException e) {
-				break nextArg;
-			}
-			boolean firstArg = modulo == 0;
-			if (firstArg) { // verify position
-				if (iToken != 0)
+				// Read argument type reference
+				try {
+					typeRef = parseQualifiedName(false);
+					if (this.abort) return null; // May be aborted by specialized parser
+				} catch (InvalidInputException e) {
 					break nextArg;
-			} else if ((iToken % modulo) != 0) {
-					break nextArg;
-			}
-			if (typeRef == null) {
-				if (firstArg && getCurrentTokenType() == TerminalTokens.TokenNameRPAREN) {
-					this.lineStarted = true;
-					return createMethodReference(receiver, null);
 				}
-				Object methodRef = createMethodReference(receiver, arguments);
-				return syntaxRecoverEmptyArgumentType(methodRef);
-			}
-			if (this.index >= this.scanner.eofPosition) {
-				int argumentStart = ((ASTNode)typeRef).sourceStart;
-				Object argument = createArgumentReference(this.scanner.getCurrentIdentifierSource(), 0, false, typeRef, null, (((long)argumentStart)<<32)+this.tokenPreviousPosition-1);
-				return syntaxRecoverArgumentType(receiver, arguments, argument);
-			}
-			if (this.index >= this.cursorLocation) {
-				if (this.completionNode instanceof CompletionOnJavadocSingleTypeReference) {
-					CompletionOnJavadocSingleTypeReference singleTypeReference = (CompletionOnJavadocSingleTypeReference) this.completionNode;
-					if (singleTypeReference.token == null || singleTypeReference.token.length == 0) {
-						Object methodRef = createMethodReference(receiver, arguments);
-						return syntaxRecoverEmptyArgumentType(methodRef);
-					}
-				}
-				if (this.completionNode instanceof CompletionOnJavadocQualifiedTypeReference) {
-					CompletionOnJavadocQualifiedTypeReference qualifiedTypeReference = (CompletionOnJavadocQualifiedTypeReference) this.completionNode;
-					if (qualifiedTypeReference.tokens == null || qualifiedTypeReference.tokens.length < qualifiedTypeReference.sourcePositions.length) {
-						Object methodRef = createMethodReference(receiver, arguments);
-						return syntaxRecoverEmptyArgumentType(methodRef);
-					}
-				}
-			}
-			iToken++;
-
-			// Read possible additional type info
-			dim = 0;
-			isVarargs = false;
-			if (readToken() == TerminalTokens.TokenNameLBRACKET) {
-				// array declaration
-				int dimStart = this.scanner.getCurrentTokenStartPosition();
-				while (readToken() == TerminalTokens.TokenNameLBRACKET) {
-					consumeToken();
-					if (readToken() != TerminalTokens.TokenNameRBRACKET) {
-						break nextArg;
-					}
-					consumeToken();
-					dimPositions[dim++] = (((long) dimStart) << 32) + this.scanner.getCurrentTokenEndPosition();
-				}
-			} else if (readToken() == TerminalTokens.TokenNameELLIPSIS) {
-				// ellipsis declaration
-				int dimStart = this.scanner.getCurrentTokenStartPosition();
-				dimPositions[dim++] = (((long) dimStart) << 32) + this.scanner.getCurrentTokenEndPosition();
-				consumeToken();
-				isVarargs = true;
-			}
-
-			// Read argument name
-			argNamePos = -1;
-			if (readToken() == TerminalTokens.TokenNameIdentifier) {
-				consumeToken();
+				boolean firstArg = modulo == 0;
 				if (firstArg) { // verify position
-					if (iToken != 1)
+					if (iToken != 0)
 						break nextArg;
-				} else if ((iToken % modulo) != 1) {
+				} else if ((iToken % modulo) != 0) {
 						break nextArg;
 				}
-				if (argName == null) { // verify that all arguments name are declared
-					if (!firstArg) {
+				if (typeRef == null) {
+					if (firstArg && getCurrentTokenType() == TerminalTokens.TokenNameRPAREN) {
+						this.lineStarted = true;
+						return createMethodReference(receiver, null);
+					}
+					Object methodRef = createMethodReference(receiver, arguments);
+					return syntaxRecoverEmptyArgumentType(methodRef);
+				}
+				if (this.index >= this.scanner.eofPosition) {
+					int argumentStart = ((ASTNode)typeRef).sourceStart;
+					Object argument = createArgumentReference(this.scanner.getCurrentIdentifierSource(), 0, false, typeRef, null, (((long)argumentStart)<<32)+this.tokenPreviousPosition-1);
+					return syntaxRecoverArgumentType(receiver, arguments, argument);
+				}
+				if (this.index >= this.cursorLocation) {
+					if (this.completionNode instanceof CompletionOnJavadocSingleTypeReference) {
+						CompletionOnJavadocSingleTypeReference singleTypeReference = (CompletionOnJavadocSingleTypeReference) this.completionNode;
+						if (singleTypeReference.token == null || singleTypeReference.token.length == 0) {
+							Object methodRef = createMethodReference(receiver, arguments);
+							return syntaxRecoverEmptyArgumentType(methodRef);
+						}
+					}
+					if (this.completionNode instanceof CompletionOnJavadocQualifiedTypeReference) {
+						CompletionOnJavadocQualifiedTypeReference qualifiedTypeReference = (CompletionOnJavadocQualifiedTypeReference) this.completionNode;
+						if (qualifiedTypeReference.tokens == null || qualifiedTypeReference.tokens.length < qualifiedTypeReference.sourcePositions.length) {
+							Object methodRef = createMethodReference(receiver, arguments);
+							return syntaxRecoverEmptyArgumentType(methodRef);
+						}
+					}
+				}
+				iToken++;
+
+				// Read possible additional type info
+				dim = 0;
+				isVarargs = false;
+				if (readToken() == TerminalTokens.TokenNameLBRACKET) {
+					// array declaration
+					int dimStart = this.scanner.getCurrentTokenStartPosition();
+					while (readToken() == TerminalTokens.TokenNameLBRACKET) {
+						consumeToken();
+						if (readToken() != TerminalTokens.TokenNameRBRACKET) {
+							break nextArg;
+						}
+						consumeToken();
+						dimPositions[dim++] = (((long) dimStart) << 32) + this.scanner.getCurrentTokenEndPosition();
+					}
+				} else if (readToken() == TerminalTokens.TokenNameELLIPSIS) {
+					// ellipsis declaration
+					int dimStart = this.scanner.getCurrentTokenStartPosition();
+					dimPositions[dim++] = (((long) dimStart) << 32) + this.scanner.getCurrentTokenEndPosition();
+					consumeToken();
+					isVarargs = true;
+				}
+
+				// Read argument name
+				argNamePos = -1;
+				if (readToken() == TerminalTokens.TokenNameIdentifier) {
+					consumeToken();
+					if (firstArg) { // verify position
+						if (iToken != 1)
+							break nextArg;
+					} else if ((iToken % modulo) != 1) {
+							break nextArg;
+					}
+					if (argName == null) { // verify that all arguments name are declared
+						if (!firstArg) {
+							break nextArg;
+						}
+					}
+					argName = this.scanner.getCurrentIdentifierSource();
+					argNamePos = (((long)this.scanner.getCurrentTokenStartPosition())<<32)+this.scanner.getCurrentTokenEndPosition();
+					iToken++;
+				} else if (argName != null) { // verify that no argument name is declared
+					break nextArg;
+				}
+
+				// Verify token position
+				if (firstArg) {
+					modulo = iToken + 1;
+				} else {
+					if ((iToken % modulo) != (modulo - 1)) {
 						break nextArg;
 					}
 				}
-				argName = this.scanner.getCurrentIdentifierSource();
-				argNamePos = (((long)this.scanner.getCurrentTokenStartPosition())<<32)+this.scanner.getCurrentTokenEndPosition();
-				iToken++;
-			} else if (argName != null) { // verify that no argument name is declared
-				break nextArg;
-			}
 
-			// Verify token position
-			if (firstArg) {
-				modulo = iToken + 1;
-			} else {
-				if ((iToken % modulo) != (modulo - 1)) {
-					break nextArg;
+				// Read separator or end arguments declaration
+				int token = readToken();
+				name = argName == null ? CharOperation.NO_CHAR : argName;
+				if (token == TerminalTokens.TokenNameCOMMA) {
+					// Create new argument
+					Object argument = createArgumentReference(name, dim, isVarargs, typeRef, dimPositions, argNamePos);
+					if (this.abort) return null; // May be aborted by specialized parser
+					arguments.add(argument);
+					consumeToken();
+					iToken++;
+				} else if (token == TerminalTokens.TokenNameRPAREN) {
+					// Create new argument
+					Object argument = createArgumentReference(name, dim, isVarargs, typeRef, dimPositions, argNamePos);
+					if (this.abort) return null; // May be aborted by specialized parser
+					arguments.add(argument);
+					consumeToken();
+					return createMethodReference(receiver, arguments);
+				} else {
+					Object argument = createArgumentReference(name, dim, isVarargs, typeRef, dimPositions, argNamePos);
+					return syntaxRecoverArgumentType(receiver, arguments, argument);
 				}
 			}
 
-			// Read separator or end arguments declaration
-			int token = readToken();
-			name = argName == null ? CharOperation.NO_CHAR : argName;
-			if (token == TerminalTokens.TokenNameCOMMA) {
-				// Create new argument
-				Object argument = createArgumentReference(name, dim, isVarargs, typeRef, dimPositions, argNamePos);
-				if (this.abort) return null; // May be aborted by specialized parser
-				arguments.add(argument);
-				consumeToken();
-				iToken++;
-			} else if (token == TerminalTokens.TokenNameRPAREN) {
-				// Create new argument
-				Object argument = createArgumentReference(name, dim, isVarargs, typeRef, dimPositions, argNamePos);
-				if (this.abort) return null; // May be aborted by specialized parser
-				arguments.add(argument);
-				consumeToken();
-				return createMethodReference(receiver, arguments);
-			} else {
-				Object argument = createArgumentReference(name, dim, isVarargs, typeRef, dimPositions, argNamePos);
-				return syntaxRecoverArgumentType(receiver, arguments, argument);
-			}
+			// Something wrong happened => Invalid input
+			throw new InvalidInputException();
+		} finally {
+			// we have to make sure that this is reset to the previous value even if an exception occurs
+			this.scanner.tokenizeWhiteSpace = tokenWhiteSpace;
 		}
-
-		// Something wrong happened => Invalid input
-		throw new InvalidInputException();
 	}
 
 		@Override
@@ -567,7 +685,13 @@ public class CompletionJavadocParser extends JavadocParser {
 	protected boolean parseTag(int previousPosition) throws InvalidInputException {
 		int startPosition = this.inlineTagStarted ? this.inlineTagStart : previousPosition;
 		boolean newLine = !this.lineStarted;
-		boolean valid = super.parseTag(previousPosition);
+		boolean valid = false;
+		try {
+			valid = super.parseTag(previousPosition);
+		}
+		catch (InvalidCursorLocation e) {
+			// catch exception and get a javadoc tag in snippet if possible
+		}
 		boolean inCompletion = (this.tagSourceStart <= (this.cursorLocation+1) && this.cursorLocation <= this.tagSourceEnd) // completion cursor is between first and last stacked identifiers
 			|| ((this.tagSourceStart == (this.tagSourceEnd+1) && this.tagSourceEnd == this.cursorLocation)); // or it's a completion on empty token
 		if (inCompletion) {
@@ -579,7 +703,7 @@ public class CompletionJavadocParser extends JavadocParser {
 			int length = this.cursorLocation+1-this.tagSourceStart;
 			char[] tag = new char[length];
 			System.arraycopy(this.source, this.tagSourceStart, tag, 0, length);
-			char[][][] tags = possibleTags(tag, newLine);
+			char[][][] tags = this.parsingSnippet ?  possibleTags(tag, false,true) : possibleTags(tag, newLine,false);
 			if (tags != null) {
 				this.completionNode = new CompletionOnJavadocTag(tag, position, startPosition, end, tags, this.allPossibleTags);
 			}
@@ -587,6 +711,16 @@ public class CompletionJavadocParser extends JavadocParser {
 		return valid;
 	}
 
+	@Override
+	protected boolean parseSnippet() throws InvalidInputException {
+		this.parsingSnippet = true;
+		return super.parseSnippet();
+	}
+
+	@Override
+	protected boolean lookForTagsInSnippets() {
+		return this.parsingSnippet;
+	}
 	@Override
 	protected boolean parseThrows() {
 		try {
