@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2020 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -788,8 +788,8 @@ public void generateCode(BlockScope currentScope, CodeStream codeStream, boolean
 public void addPatternVariables(BlockScope scope, CodeStream codeStream) {
 	// Nothing by default
 }
-public boolean containsPatternVariable() {
-	return false;
+public LocalDeclaration getPatternVariable() {
+	return null;
 }
 public void collectPatternVariablesToScope(LocalVariableBinding[] variables, BlockScope scope) {
 	new ASTVisitor() {
@@ -1365,7 +1365,9 @@ public Expression [] getPolyExpressions() {
 }
 
 public boolean isPotentiallyCompatibleWith(TypeBinding targetType, Scope scope) {
-	return isCompatibleWith(targetType, scope); // for all but functional expressions, potential compatibility is the same as compatibility.
+	// A class instance creation expression, a method invocation expression, or an
+	// expression of a standalone form (§15.2) is potentially compatible with any type.
+	return true;
 }
 
 protected Constant optimizedNullComparisonConstant() {
