@@ -367,6 +367,12 @@ public ConstructorDeclaration createDefaultConstructorForRecord(boolean needExpl
 //	constructor.modifiers |= ClassFileConstants.AccPublic; // JLS 14 8.10.5
 	constructor.arguments = getArgumentsFromComponents(this.recordComponents);
 
+	for (int i = 0, max = constructor.arguments.length; i < max; i++) {
+		if ((constructor.arguments[i].bits & ASTNode.HasTypeAnnotations) != 0) {
+			constructor.bits |= ASTNode.HasTypeAnnotations;
+			break;
+		}
+	}
 	constructor.declarationSourceStart = constructor.sourceStart =
 			constructor.bodyStart = this.sourceStart;
 	constructor.declarationSourceEnd =
@@ -613,7 +619,7 @@ public AbstractMethodDeclaration declarationOf(MethodBinding methodBinding) {
  */
 public RecordComponent declarationOf(RecordComponentBinding recordComponentBinding) {
 	if (recordComponentBinding != null && this.recordComponents != null) {
-		for (int i = 0, max = this.fields.length; i < max; i++) {
+		for (int i = 0, max = this.recordComponents.length; i < max; i++) {
 			RecordComponent recordComponent;
 			if ((recordComponent = this.recordComponents[i]).binding == recordComponentBinding)
 				return recordComponent;
@@ -656,8 +662,13 @@ public CompilationUnitDeclaration getCompilationUnitDeclaration() {
 	return null;
 }
 
-/* only for records */
+/**
+ * This is applicable only for records - ideally get the canonical constructor, if not
+ * get a constructor and at the client side tentatively marked as canonical constructor
+ * which gets checked at the binding time. If there are no constructors, then null is returned.
+ **/
 public ConstructorDeclaration getConstructor(Parser parser) {
+	ConstructorDeclaration cd = null;
 	if (this.methods != null) {
 		for (int i = this.methods.length; --i >= 0;) {
 			AbstractMethodDeclaration am;
@@ -679,17 +690,19 @@ public ConstructorDeclaration getConstructor(Parser parser) {
 						return ccd;
 					}
 					// now we are looking at a "normal" constructor
-					if (this.recordComponents == null && am.arguments == null)
+					if ((this.recordComponents == null || this.recordComponents.length == 0)
+							&& am.arguments == null)
 						return (ConstructorDeclaration) am;
+					cd = (ConstructorDeclaration) am; // just return the last constructor
 				}
 			}
 		}
 	}
-	/* At this point we can only say that there is high possibility that there is a constructor
-	 * If it is a CCD, then definitely it is there (except for empty one); else we need to check
-	 * the bindings to say that there is a canonical constructor. To take care at binding resolution time.
-	 */
-	return null;
+//	/* At this point we can only say that there is high possibility that there is a constructor
+//	 * If it is a CCD, then definitely it is there (except for empty one); else we need to check
+//	 * the bindings to say that there is a canonical constructor. To take care at binding resolution time.
+//	 */
+	return cd; // the last constructor
 }
 
 /**
@@ -717,6 +730,12 @@ public void generateCode(ClassFile enclosingClassFile) {
 			enclosingClassFile.recordInnerClasses(this.binding);
 			classFile.recordInnerClasses(this.binding);
 		}
+		SourceTypeBinding nestHost = this.binding.getNestHost();
+		if (nestHost != null && !TypeBinding.equalsEquals(nestHost, this.binding)) {
+			ClassFile ocf = enclosingClassFile.outerMostEnclosingClassFile();
+			if (ocf != null)
+				ocf.recordNestMember(this.binding);
+		}
 		TypeVariableBinding[] typeVariables = this.binding.typeVariables();
 		for (int i = 0, max = typeVariables.length; i < max; i++) {
 			TypeVariableBinding typeVariableBinding = typeVariables[i];
@@ -821,7 +840,10 @@ public boolean hasErrors() {
  *	Common flow analysis for all types
  */
 private void internalAnalyseCode(FlowContext flowContext, FlowInfo flowInfo) {
-	checkYieldUsage();
+	if (CharOperation.equals(this.name, TypeConstants.YIELD)) {
+		this.scope.problemReporter().validateRestrictedKeywords(this.name, this);
+	}
+
 	if (!this.binding.isUsed() && this.binding.isOrEnclosedByPrivateType()) {
 		if (!this.scope.referenceCompilationUnit().compilationResult.hasSyntaxError) {
 			this.scope.problemReporter().unusedPrivateType(this);
@@ -944,18 +966,6 @@ private void internalAnalyseCode(FlowContext flowContext, FlowInfo flowInfo) {
 	}
 }
 
-private void checkYieldUsage() {
-	long sourceLevel = this.scope.compilerOptions().sourceLevel;
-	if (sourceLevel < ClassFileConstants.JDK14 || this.name == null ||
-			!("yield".equals(new String(this.name)))) //$NON-NLS-1$
-		return;
-	if (sourceLevel >= ClassFileConstants.JDK14) {
-		this.scope.problemReporter().switchExpressionsYieldTypeDeclarationError(this);
-	} else {
-		this.scope.problemReporter().switchExpressionsYieldTypeDeclarationWarning(this);
-	}
-}
-
 private SimpleSetOfCharArray getJUnitMethodSourceValues() {
 	SimpleSetOfCharArray junitMethodSourceValues = new SimpleSetOfCharArray();
 	for (AbstractMethodDeclaration methodDeclaration : this.methods) {
@@ -1310,7 +1320,7 @@ public void resolve() {
 			}
 		}
 
-		if ((this.bits & ASTNode.UndocumentedEmptyBlock) != 0) {
+		if ((this.bits & ASTNode.UndocumentedEmptyBlock) != 0 && this.nRecordComponents == 0) {
 			this.scope.problemReporter().undocumentedEmptyBlock(this.bodyStart-1, this.bodyEnd);
 		}
 		boolean needSerialVersion =
@@ -1512,7 +1522,7 @@ public void resolve() {
 				reporter.javadocMissing(this.sourceStart, this.sourceEnd, severity, javadocModifiers);
 			}
 		}
-		updateNestInfo();
+		updateNestHost();
 		FieldDeclaration[] fieldsDecls = this.fields;
 		if (fieldsDecls != null) {
 			for (FieldDeclaration fieldDeclaration : fieldsDecls)
@@ -1853,13 +1863,12 @@ private SourceTypeBinding findNestHost() {
 	return classScope != null ? classScope.referenceContext.binding : null;
 }
 
-void updateNestInfo() {
+void updateNestHost() {
 	if (this.binding == null)
 		return;
 	SourceTypeBinding nestHost = findNestHost();
 	if (nestHost != null && !this.binding.equals(nestHost)) {// member
 		this.binding.setNestHost(nestHost);
-		nestHost.addNestMember(this.binding);
 	}
 }
 public boolean isPackageInfo() {
