@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2020 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -65,6 +65,7 @@ public class MethodBinding extends Binding {
 	public TypeVariableBinding[] typeVariables = Binding.NO_TYPE_VARIABLES;
 	char[] signature;
 	public long tagBits;
+	public int extendedTagBits = 0; // See values in the interface ExtendedTagBits
 	// Used only for constructors
 	protected AnnotationBinding [] typeAnnotations = Binding.NO_ANNOTATIONS;
 
@@ -803,6 +804,12 @@ public final boolean isConstructor() {
 	return this.selector == TypeConstants.INIT;
 }
 
+/* Answer true if the method is a canonical constructor
+*/
+public final boolean isCanonicalConstructor() {
+	return (this.extendedTagBits & ExtendedTagBits.IsCanonicalConstructor) != 0;
+}
+
 /* Answer true if the receiver is a compact constructor
 */
 public final boolean isCompactConstructor() {
@@ -846,6 +853,14 @@ public final boolean isImplementing() {
 	return (this.modifiers & ExtraCompilerModifiers.AccImplementing) != 0;
 }
 
+
+/* Answer true if the method is an implicit method - only for records
+*/
+public final boolean isImplicit() {
+	return (this.extendedTagBits & ExtendedTagBits.isImplicit) != 0;
+}
+
+
 /*
  * Answer true if the receiver is a "public static void main(String[])" method
  */
@@ -1081,7 +1096,7 @@ public final char[] signature() /* (ILjava/lang/Thread;)Ljava/lang/Object; */ {
 			}
 		}
 
-		if (this instanceof SyntheticMethodBinding) {
+		if ((this instanceof SyntheticMethodBinding) && (!this.declaringClass.isRecord())) {
 			targetParameters = ((SyntheticMethodBinding)this).targetMethod.parameters;
 		}
 	}
@@ -1449,4 +1464,38 @@ public void updateTypeVariableBinding(TypeVariableBinding previousBinding, TypeV
 		}
 	}
 }
+
+/**
+ * Identifies whether the method has Polymorphic signature based on <a href=https://docs.oracle.com/javase/specs/jls/se11/html/jls-15.html#jls-15.12.3>jls-15.12.3</a><br/>
+ *
+ * Definition reproduced here. <br/><br/>
+ *
+ * A method is signature polymorphic if all of the following are true:
+ *  <li> It is declared in the java.lang.invoke.MethodHandle class or the java.lang.invoke.VarHandle class. </li>
+ *  <li> It has a single variable arity parameter (§8.4.1) whose declared type is Object[]. </li>
+ *  <li> It is native. </li>
+ * <br/>
+ * @param  scope
+ * @return true if the method has Polymorphic Signature
+ */
+public boolean hasPolymorphicSignature(Scope scope) {
+	if ((this.tagBits & TagBits.AnnotationPolymorphicSignature) != 0) {
+		return true;
+	}
+	if (this.isNative()	&& this.isVarargs() && this.parameters.length == 1) {
+		/*
+		 *  here type will be arrayType we will come here only if the method is of type
+		 *  varargs(represented by arraytype) and with only one parameter.
+		 */
+		if (this.parameters[0].leafComponentType().id == TypeIds.T_JavaLangObject) {
+			ReferenceBinding declaringClassLocal = this.declaringClass;
+			if ((declaringClassLocal != null) && (declaringClassLocal.id == scope.getJavaLangInvokeMethodHandle().id
+					|| declaringClassLocal.id == scope.getJavaLangInvokeVarHandle().id)) {
+				return true;
+			}
+		}
+	}
+
+	return false;
+}
 }
