@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2020 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,7 +13,9 @@
  *******************************************************************************/
 package org.eclipse.jdt.internal.compiler.parser;
 
+import java.util.ArrayList;
 import java.util.List;
+import java.util.Map;
 
 import org.eclipse.jdt.core.compiler.CharOperation;
 import org.eclipse.jdt.core.compiler.InvalidInputException;
@@ -68,6 +70,9 @@ public class JavadocParser extends AbstractCommentParser {
 	// see "https://bugs.eclipse.org/bugs/show_bug.cgi?id=222900"
 	private int tagWaitingForDescription;
 
+	private ArrayList<String> regionNames = new ArrayList<>();
+	private int regionPosition = -1;
+
 	public JavadocParser(Parser sourceParser) {
 		super(sourceParser);
 		this.kind = COMPIL_PARSER | TEXT_VERIF;
@@ -346,8 +351,73 @@ public class JavadocParser extends AbstractCommentParser {
 		this.tagValue = TAG_OTHERS_VALUE;
 	}
 
+	@Override
+	protected Object createSnippetTag() {
+		this.tagValue = TAG_SNIPPET_VALUE;
+		return this.tagValue;
+	}
+
+	@Override
+	protected Object createSnippetRegion(String name, List<Object> tags, Object snippetTag, boolean isDummyRegion, boolean considerPrevTag) {
+		if(this.regionNames.contains(name)) {
+			if(this.reportProblems) {
+				int startPos= this.lineEnd -this.scanner.getCurrentTokenString().length() +2;
+				if(this.regionPosition>0)
+					startPos = startPos+this.regionPosition;
+				this.sourceParser.problemReporter().javadocInvalidSnippetDuplicateRegions(startPos-4, startPos+1);
+			}
+			this.setSnippetIsValid(snippetTag, false);
+			this.setSnippetError(snippetTag, "Duplicate regions"); //$NON-NLS-1$
+		}
+		else {
+			if(name!=null)
+				this.regionNames.add(name);
+		}
+
+		if (tags != null && tags.size() > 0) {
+			return tags.get(0);
+		}
+		return name;
+	}
+
+	@Override
+	protected void setSnippetIsValid(Object obj, boolean value) {
+		//do nothing;
+	}
+
+	@Override
+	protected void setSnippetError(Object obj, String value) {
+		//do nothing;
+	}
+
+	@Override
+	protected void setSnippetID(Object tag, String value) {
+		// do nothing
+
+	}
+
+	@Override
+	protected Object createSnippetInnerTag(String tagName, int start, int end) {
+		return tagName;
+	}
+
+	@Override
+	protected void addTagProperties(Object Tag, Map<String, Object> map, int tagCount) {
+		return;
+	}
+
+	@Override
+	protected void addSnippetInnerTag(Object tag, Object snippetTag) {
+		this.tagValue = TAG_OTHERS_VALUE;
+	}
+
 	@Override
 	protected Object createTypeReference(int primitiveToken) {
+		return createTypeReference(primitiveToken, false);
+	}
+
+	@Override
+	protected Object createTypeReference(int primitiveToken, boolean canBeModule) {
 		TypeReference typeRef = null;
 		int size = this.identifierLengthStack[this.identifierLengthPtr];
 		if (size == 1) { // Single Type ref
@@ -355,13 +425,14 @@ public class JavadocParser extends AbstractCommentParser {
 						this.identifierStack[this.identifierPtr],
 						this.identifierPositionStack[this.identifierPtr],
 						this.tagSourceStart,
-						this.tagSourceEnd);
+						this.tagSourceEnd,
+						canBeModule);
 		} else if (size > 1) { // Qualified Type ref
 			char[][] tokens = new char[size][];
 			System.arraycopy(this.identifierStack, this.identifierPtr - size + 1, tokens, 0, size);
 			long[] positions = new long[size];
 			System.arraycopy(this.identifierPositionStack, this.identifierPtr - size + 1, positions, 0, size);
-			typeRef = new JavadocQualifiedTypeReference(tokens, positions, this.tagSourceStart, this.tagSourceEnd);
+			typeRef = new JavadocQualifiedTypeReference(tokens, positions, this.tagSourceStart, this.tagSourceEnd, canBeModule);
 		}
 		return typeRef;
 	}
@@ -388,13 +459,14 @@ public class JavadocParser extends AbstractCommentParser {
 						this.identifierStack[this.identifierPtr],
 						this.identifierPositionStack[this.identifierPtr],
 						this.tagSourceStart,
-						this.tagSourceEnd);
+						this.tagSourceEnd,
+						false);
 		} else if (newSize > 1) { // Qualified Type ref
 			char[][] tokens = new char[newSize][];
 			System.arraycopy(this.identifierStack, this.identifierPtr - newSize + 1, tokens, 0, newSize);
 			long[] positions = new long[newSize];
 			System.arraycopy(this.identifierPositionStack, this.identifierPtr - newSize + 1, positions, 0, newSize);
-			typeRef = new JavadocQualifiedTypeReference(tokens, positions, this.tagSourceStart, this.tagSourceEnd);
+			typeRef = new JavadocQualifiedTypeReference(tokens, positions, this.tagSourceStart, this.tagSourceEnd, false);
 		} else {
 			this.lastIdentifierEndPosition++;
 		}
@@ -739,6 +811,16 @@ public class JavadocParser extends AbstractCommentParser {
 				} else if (length == TAG_SUMMARY_LENGTH && CharOperation.equals(TAG_SUMMARY, tagName, 0, length)) {
 					this.tagValue = TAG_SUMMARY_VALUE;
 					this.tagWaitingForDescription = this.tagValue;
+				} else if (length == TAG_SNIPPET_LENGTH && CharOperation.equals(TAG_SNIPPET, tagName, 0, length)) {
+					this.tagValue = TAG_SNIPPET_VALUE;
+					this.tagWaitingForDescription = this.tagValue;
+					if (this.inlineTagStarted) {
+						valid = parseSnippet();
+					}
+				}else if (length> TAG_SNIPPET_LENGTH && CharOperation.prefixEquals(TAG_SNIPPET, tagName)) {
+					if (this.reportProblems ) {
+						this.sourceParser.problemReporter().javadocInvalidSnippet(this.tagSourceStart, this.tagSourceEnd);
+					}
 				}
 				break;
 			case 't':
@@ -797,8 +879,7 @@ public class JavadocParser extends AbstractCommentParser {
 			}
 			// see bug https://bugs.eclipse.org/bugs/show_bug.cgi?id=267833
 			// Report a problem if a block tag is being used in the context of an inline tag and vice versa.
-			if ((this.inlineTagStarted && JAVADOC_TAG_TYPE[this.tagValue] == TAG_TYPE_BLOCK)
-					|| (!this.inlineTagStarted && JAVADOC_TAG_TYPE[this.tagValue] == TAG_TYPE_INLINE)) {
+			if ((this.inlineTagStarted ? JAVADOC_TAG_TYPE[this.tagValue] == TAG_TYPE_BLOCK : JAVADOC_TAG_TYPE[this.tagValue] == TAG_TYPE_INLINE)) {
 				valid = false;
 				this.tagValue = TAG_OTHERS_VALUE;
 				this.tagWaitingForDescription = NO_TAG_VALUE;
@@ -923,6 +1004,24 @@ public class JavadocParser extends AbstractCommentParser {
 		this.tagWaitingForDescription = NO_TAG_VALUE;
 	}
 
+	@Override
+	protected void  pushSnippetText(char[] text, int start, int end, boolean addNewLine, Object snippetTag) {
+		// The tag gets its description => clear the flag
+		this.tagWaitingForDescription = TAG_SNIPPET_VALUE;
+	}
+
+	@Override
+	protected void closeJavaDocRegion(String name, Object snippetTag, int end){
+		this.regionNames.remove(name);
+		//do nothing
+	}
+
+	@Override
+	protected void pushExternalSnippetText(char[] text, int start, int end, boolean addNewLine, Object snippetTag) {
+		// The tag gets its description => clear the flag
+		this.tagWaitingForDescription = TAG_SNIPPET_VALUE;
+	}
+
 	/*
 	 * Push a throws type ref in ast node stack.
 	 */
@@ -1174,4 +1273,19 @@ public class JavadocParser extends AbstractCommentParser {
 
 	}
 
+
+	@Override
+	/**	 * call at the end of snippet, so clear regionNames
+	 */
+	protected boolean areRegionsClosed() {
+		int size = this.regionNames.size();
+		this.regionNames.clear();
+		return size==0;
+	}
+
+	@Override
+	protected void setRegionPosition(int currentPosition) {
+		this.regionPosition=currentPosition;
+
+	}
 }
