@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -53,6 +53,9 @@ public interface JavadocTagConstants {
 	public static final char[] TAG_API_NOTE = "apiNote".toCharArray(); //$NON-NLS-1$
 	public static final char[] TAG_IMPL_SPEC = "implSpec".toCharArray(); //$NON-NLS-1$
 	public static final char[] TAG_IMPL_NOTE = "implNote".toCharArray(); //$NON-NLS-1$
+	public static final char[] TAG_SNIPPET = "snippet".toCharArray(); //$NON-NLS-1$
+	public static final char[] TAG_HIGHLIGHT = "highlight".toCharArray(); //$NON-NLS-1$
+	public static final char[] TAG_REPLACE = "replace".toCharArray(); //$NON-NLS-1$
 
 	// tags lengthes
 	public static final int TAG_DEPRECATED_LENGTH = TAG_DEPRECATED.length;
@@ -84,6 +87,10 @@ public interface JavadocTagConstants {
 	public static final int TAG_API_NOTE_LENGTH = TAG_API_NOTE.length;
 	public static final int TAG_IMPL_SPEC_LENGTH = TAG_IMPL_SPEC.length;
 	public static final int TAG_IMPL_NOTE_LENGTH = TAG_IMPL_NOTE.length;
+	public static final int TAG_SNIPPET_LENGTH = TAG_SNIPPET.length;
+	public static final int TAG_HIGHLIGHT_LENGTH = TAG_HIGHLIGHT.length;
+	public static final int TAG_REPLACE_LENGTH = TAG_REPLACE.length;
+
 
 	// tags value
 	public static final int NO_TAG_VALUE = 0;
@@ -116,6 +123,9 @@ public interface JavadocTagConstants {
 	public static final int TAG_API_NOTE_VALUE = 27;
 	public static final int TAG_IMPL_SPEC_VALUE = 28;
 	public static final int TAG_IMPL_NOTE_VALUE = 29;
+	public static final int TAG_SNIPPET_VALUE = 30;
+	public static final int TAG_HIGHLIGHT_VALUE = 31;
+	public static final int TAG_REPLACE_VALUE = 32;
 	public static final int TAG_OTHERS_VALUE = 100;
 	// Tag names array
 	public static final char[][] TAG_NAMES = {
@@ -149,6 +159,9 @@ public interface JavadocTagConstants {
 		TAG_API_NOTE,			/* 27 */
 		TAG_IMPL_SPEC,			/* 28 */
 		TAG_IMPL_NOTE,			/* 29 */
+		TAG_SNIPPET,			/* 30 */
+		TAG_HIGHLIGHT,			/* 31 */
+		TAG_REPLACE,			/* 32 */
 	};
 
 	// tags expected positions
@@ -162,6 +175,8 @@ public interface JavadocTagConstants {
 	 */
 	public final static int BLOCK_IDX = 0;
 	public final static int INLINE_IDX = 1;
+	public final static int SNIPPET_IDX = 2;
+
 
 	// href tag
 	public final static char[] HREF_TAG = {'h', 'r', 'e', 'f'};
@@ -194,7 +209,21 @@ public interface JavadocTagConstants {
 		// since 11
 		{},
 		//since 12
-		{}
+		{},
+		//since 13
+		{},
+		//since 14
+		{},
+		//since 15
+		{},
+		//since 16
+		{},
+		// since 17
+		{},
+		// since 18
+		{},
+		// since 19
+		{},
 	};
 	public static final char[][][] INLINE_TAGS = {
 		// since 1.0
@@ -222,15 +251,37 @@ public interface JavadocTagConstants {
 		// since 11
 		{},
 		//since 12
-		{TAG_SYSTEM_PROPERTY}
+		{TAG_SYSTEM_PROPERTY},
+		//since 13
+		{},
+		//since 14
+		{},
+		//since 15
+		{},
+		//since 16
+		{},
+		//since 17
+		{},
+		//since 18
+		{ TAG_SNIPPET },
+		//since 19
+		{}
 	};
+	public static final char[][][] IN_SNIPPET_TAGS = {
+		//since 18
+			{ TAG_HIGHLIGHT, TAG_REPLACE, TAG_LINK }
+	};
+	public final static int IN_SNIPPET_TAGS_LENGTH = IN_SNIPPET_TAGS.length;
 	public final static int INLINE_TAGS_LENGTH = INLINE_TAGS.length;
+	public final static int SNIPPET_TAGS_LENGTH = IN_SNIPPET_TAGS.length;
+
 	public final static int BLOCK_TAGS_LENGTH = BLOCK_TAGS.length;
 	public final static int ALL_TAGS_LENGTH = BLOCK_TAGS_LENGTH+INLINE_TAGS_LENGTH;
 
 	public final static short TAG_TYPE_NONE = 0;
 	public final static short TAG_TYPE_INLINE = 1;
 	public final static short TAG_TYPE_BLOCK = 2;
+	public final static short TAG_TYPE_IN_SNIPPET = 3;
 	public static final short[] JAVADOC_TAG_TYPE = {
 		TAG_TYPE_NONE, 		// NO_TAG_VALUE = 0;
 		TAG_TYPE_BLOCK,		// TAG_DEPRECATED_VALUE = 1;
@@ -262,7 +313,10 @@ public interface JavadocTagConstants {
 		TAG_TYPE_BLOCK,		// TAG_API_NOTE = 27;
 		TAG_TYPE_BLOCK,		// TAG_IMPL_SPEC = 28;
 		TAG_TYPE_BLOCK,		// TAG_IMPL_NOTE = 29;
-	};
+		TAG_TYPE_INLINE,	// TAG_SNIPPET_VALUE = 30;
+		TAG_TYPE_IN_SNIPPET,// TAG_HIGHLIGHT_VALUE = 31;
+		TAG_TYPE_IN_SNIPPET,// TAG_HIGHLIGHT_VALUE = 32;
+ 	};
 	/*
 	 * Tags usage
 	 */
@@ -284,6 +338,9 @@ public interface JavadocTagConstants {
 		TAG_API_NOTE,
 		TAG_IMPL_SPEC,
 		TAG_IMPL_NOTE,
+		TAG_SNIPPET,
+		TAG_HIGHLIGHT,
+		TAG_REPLACE
 	};
 	public static final char[][] COMPILATION_UNIT_TAGS = {};
 	public static final char[][] CLASS_TAGS = {
@@ -308,6 +365,9 @@ public interface JavadocTagConstants {
 		TAG_API_NOTE,
 		TAG_IMPL_SPEC,
 		TAG_IMPL_NOTE,
+		TAG_SNIPPET,
+		TAG_HIGHLIGHT,
+		TAG_REPLACE
 	};
 	public static final char[][] FIELD_TAGS = {
 		TAG_SEE,
@@ -326,9 +386,12 @@ public interface JavadocTagConstants {
 		TAG_INDEX,
 		TAG_HIDDEN,
 		TAG_SUMMARY,
-		TAG_API_NOTE, 
-		TAG_IMPL_SPEC, 
+		TAG_API_NOTE,
+		TAG_IMPL_SPEC,
 		TAG_IMPL_NOTE,
+		TAG_SNIPPET,
+		TAG_HIGHLIGHT,
+		TAG_REPLACE
 	};
 	public static final char[][] METHOD_TAGS = {
 		TAG_SEE,
@@ -354,6 +417,9 @@ public interface JavadocTagConstants {
 		TAG_API_NOTE,
 		TAG_IMPL_SPEC,
 		TAG_IMPL_NOTE,
+		TAG_SNIPPET,
+		TAG_HIGHLIGHT,
+		TAG_REPLACE
 	};
 	public static final char[][] MODULE_TAGS = {
 			TAG_SEE,
@@ -377,5 +443,8 @@ public interface JavadocTagConstants {
 			TAG_API_NOTE,
 			TAG_IMPL_SPEC,
 			TAG_IMPL_NOTE,
+			TAG_SNIPPET,
+			TAG_HIGHLIGHT,
+			TAG_REPLACE
 		};
 }
