@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2004, 2021 IBM Corporation and others.
+ * Copyright (c) 2004, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -1137,12 +1137,8 @@ public class ASTParser {
 							} catch(JavaModelException e) {
 								// an error occured accessing the java element
 								StringWriter stringWriter = new StringWriter();
-								PrintWriter writer = null;
-								try {
-									writer = new PrintWriter(stringWriter);
+								try (PrintWriter writer = new PrintWriter(stringWriter)) {
 									e.printStackTrace(writer);
-								} finally {
-									if (writer != null) writer.close();
 								}
 								throw new IllegalStateException(String.valueOf(stringWriter.getBuffer()));
 							}
@@ -1211,12 +1207,8 @@ public class ASTParser {
 						} catch(JavaModelException e) {
 							// an error occured accessing the java element
 							StringWriter stringWriter = new StringWriter();
-							PrintWriter writer = null;
-							try {
-								writer = new PrintWriter(stringWriter);
+							try (PrintWriter writer = new PrintWriter(stringWriter)) {
 								e.printStackTrace(writer);
-							} finally {
-								if (writer != null) writer.close();
 							}
 							throw new IllegalStateException(String.valueOf(stringWriter.getBuffer()));
 						}
@@ -1273,7 +1265,8 @@ public class ASTParser {
 								sourceUnit,
 								searcher,
 								this.compilerOptions,
-								flags);
+								flags,
+								this.project);
 						needToResolveBindings = false;
 					}
 					CompilationUnit result = CompilationUnitResolver.convert(
@@ -1286,7 +1279,8 @@ public class ASTParser {
 						needToResolveBindings ? new DefaultBindingResolver.BindingTables() : null,
 						flags,
 						monitor,
-						this.project != null);
+						this.project != null,
+						this.project);
 					result.setTypeRoot(this.typeRoot);
 					return result;
 				} finally {
