@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2021 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -402,6 +402,23 @@ public abstract class ASTVisitor {
 		return true;
 	}
 
+	/**
+	 * Visits the given type-specific AST node.
+	 * <p>
+	 * The default implementation does nothing and return true.
+	 * Subclasses may reimplement.
+	 * </p>
+	 *
+	 * @param node the node to visit
+	 * @return <code>true</code> if the children of this node should be
+	 * visited, and <code>false</code> if the children of this node should
+	 * be skipped
+	 * @since 3.28
+	 */
+	public boolean visit(CaseDefaultExpression node) {
+		return true;
+	}
+
 	/**
 	 * Visits the given type-specific AST node.
 	 * <p>
@@ -745,6 +762,23 @@ public abstract class ASTVisitor {
 		return true;
 	}
 
+	/**
+	 * Visits the given type-specific AST node.
+	 * <p>
+	 * The default implementation does nothing and return true.
+	 * Subclasses may reimplement.
+	 * </p>
+	 *
+	 * @param node the node to visit
+	 * @return <code>true</code> if the children of this node should be
+	 * visited, and <code>false</code> if the children of this node should
+	 * be skipped
+	 * @since 3.28
+	 */
+	public boolean visit(GuardedPattern node) {
+		return true;
+	}
+
 	/**
 	 * Visits the given type-specific AST node.
 	 * <p>
@@ -864,6 +898,45 @@ public abstract class ASTVisitor {
 		return this.visitDocTags;
 	}
 
+	/**
+	 * Visits the given AST node.
+	 * <p>
+	 * Unlike other node types, the boolean returned by the default
+	 * implementation is controlled by a constructor-supplied
+	 * parameter  {@link #ASTVisitor(boolean) ASTVisitor(boolean)}
+	 * which is <code>false</code> by default.
+	 * Subclasses may reimplement.
+	 * </p>
+	 *
+	 * @param node the node to visit
+	 * @return <code>true</code> if the children of this node should be
+	 * visited, and <code>false</code> if the children of this node should
+	 * be skipped
+	 * @see #ASTVisitor()
+	 * @see #ASTVisitor(boolean)
+	 * @since 3.30
+	 */
+	public boolean visit(JavaDocRegion node) {
+		return this.visitDocTags;
+	}
+
+	/**
+	 * Visits the given type-specific AST node.
+	 * <p>
+	 * The default implementation does nothing and return true.
+	 * Subclasses may reimplement.
+	 * </p>
+	 *
+	 * @param node the node to visit
+	 * @return <code>true</code> if the children of this node should be
+	 * visited, and <code>false</code> if the children of this node should
+	 * be skipped
+	 * @since 3.31
+	 */
+	public boolean visit(JavaDocTextElement node) {
+		return true;
+	}
+
 	/**
 	 * Visits the given type-specific AST node.
 	 * <p>
@@ -1145,6 +1218,23 @@ public abstract class ASTVisitor {
 		return true;
 	}
 
+	/**
+	 * Visits the given type-specific AST node.
+	 * <p>
+	 * The default implementation does nothing and return true.
+	 * Subclasses may reimplement.
+	 * </p>
+	 *
+	 * @param node the node to visit
+	 * @return <code>true</code> if the children of this node should be
+	 * visited, and <code>false</code> if the children of this node should
+	 * be skipped
+	 * @since 3.28
+	 */
+	public boolean visit(NullPattern node) {
+		return true;
+	}
+
 	/**
 	 * Visits the given type-specific AST node.
 	 * <p>
@@ -1394,6 +1484,23 @@ public abstract class ASTVisitor {
 		return true;
 	}
 
+	/**
+	 * Visits the given type-specific AST node.
+	 * <p>
+	 * The default implementation does nothing and return true.
+	 * Subclasses may reimplement.
+	 * </p>
+	 *
+	 * @param node the node to visit
+	 * @return <code>true</code> if the children of this node should be
+	 * visited, and <code>false</code> if the children of this node should
+	 * be skipped
+	 * @since 3.32
+	 */
+	public boolean visit(RecordPattern node) {
+		return true;
+	}
+
 	/**
 	 * Visits the given type-specific AST node.
 	 * <p>
@@ -1641,6 +1748,23 @@ public abstract class ASTVisitor {
 		return true;
 	}
 
+	/**
+	 * Visits the given type-specific AST node.
+	 * <p>
+	 * The default implementation does nothing and return true.
+	 * Subclasses may reimplement.
+	 * </p>
+	 *
+	 * @param node the node to visit
+	 * @return <code>true</code> if the children of this node should be
+	 * visited, and <code>false</code> if the children of this node should
+	 * be skipped
+	 * @since 3.30
+	 */
+	public boolean visit(TagProperty node) {
+		return true;
+	}
+
 
 	/**
 	 * Visits the given type-specific AST node.
@@ -1807,6 +1931,23 @@ public abstract class ASTVisitor {
 		return true;
 	}
 
+	/**
+	 * Visits the given type-specific AST node.
+	 * <p>
+	 * The default implementation does nothing and return true.
+	 * Subclasses may reimplement.
+	 * </p>
+	 *
+	 * @param node the node to visit
+	 * @return <code>true</code> if the children of this node should be
+	 * visited, and <code>false</code> if the children of this node should
+	 * be skipped
+	 * @since 3.28
+	 */
+	public boolean visit(TypePattern node) {
+		return true;
+	}
+
 	/**
 	 * Visits the given type-specific AST node.
 	 * <p>
@@ -2103,6 +2244,19 @@ public abstract class ASTVisitor {
 		// default implementation: do nothing
 	}
 
+	/**
+	 * End of visit the given type-specific AST node.
+	 * <p>
+	 * The default implementation does nothing. Subclasses may reimplement.
+	 * </p>
+	 *
+	 * @param node the node to visit
+	 * @since 3.28
+	 */
+	public void endVisit(CaseDefaultExpression node) {
+		// default implementation: do nothing
+	}
+
 	/**
 	 * End of visit the given type-specific AST node.
 	 * <p>
@@ -2362,6 +2516,19 @@ public abstract class ASTVisitor {
 		// default implementation: do nothing
 	}
 
+	/**
+	 * End of visit the given type-specific AST node.
+	 * <p>
+	 * The default implementation does nothing. Subclasses may reimplement.
+	 * </p>
+	 *
+	 * @param node the node to visit
+	 * @since 3.28
+	 */
+	public void endVisit(GuardedPattern node) {
+		// default implementation: do nothing
+	}
+
 	/**
 	 * End of visit the given type-specific AST node.
 	 * <p>
@@ -2434,6 +2601,32 @@ public abstract class ASTVisitor {
 		// default implementation: do nothing
 	}
 
+	/**
+	 * End of visit the given type-specific AST node.
+	 * <p>
+	 * The default implementation does nothing. Subclasses may reimplement.
+	 * </p>
+	 *
+	 * @param node the node to visit
+	 * @since 3.30
+	 */
+	public void endVisit(JavaDocRegion node) {
+		// default implementation: do nothing
+	}
+
+	/**
+	 * End of visit the given type-specific AST node.
+	 * <p>
+	 * The default implementation does nothing. Subclasses may reimplement.
+	 * </p>
+	 *
+	 * @param node the node to visit
+	 * @since 3.32
+	 */
+	public void endVisit(JavaDocTextElement node) {
+		// default implementation: do nothing
+	}
+
 	/**
 	 * End of visit the given type-specific AST node.
 	 * <p>
@@ -2643,6 +2836,19 @@ public abstract class ASTVisitor {
 		// default implementation: do nothing
 	}
 
+	/**
+	 * End of visit the given type-specific AST node.
+	 * <p>
+	 * The default implementation does nothing. Subclasses may reimplement.
+	 * </p>
+	 *
+	 * @param node the node to visit
+	 * @since 3.28
+	 */
+	public void endVisit(NullPattern node) {
+		// default implementation: do nothing
+	}
+
 	/**
 	 * End of visit the given type-specific AST node.
 	 * <p>
@@ -2832,6 +3038,19 @@ public abstract class ASTVisitor {
 		// default implementation: do nothing
 	}
 
+	/**
+	 * End of visit the given type-specific AST node.
+	 * <p>
+	 * The default implementation does nothing. Subclasses may re implement.
+	 * </p>
+	 *
+	 * @param node the node to visit
+	 * @since 3.31
+	 * @noreference This method is not intended to be referenced by clients.
+	 */
+	public void endVisit(RecordPattern node) {
+		// default implementation: do nothing
+	}
 
 	/**
 	 * End of visit the given type-specific AST node.
@@ -3017,6 +3236,19 @@ public abstract class ASTVisitor {
 		// default implementation: do nothing
 	}
 
+	/**
+	 * End of visit the given type-specific AST node.
+	 * <p>
+	 * The default implementation does nothing. Subclasses may reimplement.
+	 * </p>
+	 *
+	 * @param node the node to visit
+	 * @since 3.30
+	 */
+	public void endVisit(TagProperty node) {
+		// default implementation: do nothing
+	}
+
 	/**
 	 * End of visit the given type-specific AST node.
 	 * <p>
@@ -3141,6 +3373,19 @@ public abstract class ASTVisitor {
 		// default implementation: do nothing
 	}
 
+	/**
+	 * End of visit the given type-specific AST node.
+	 * <p>
+	 * The default implementation does nothing. Subclasses may reimplement.
+	 * </p>
+	 *
+	 * @param node the node to visit
+	 * @since 3.28
+	 */
+	public void endVisit(TypePattern node) {
+		// default implementation: do nothing
+	}
+
 	/**
 	 * End of visit the given type-specific AST node.
 	 * <p>
