@@ -757,6 +757,8 @@ class DefaultBindingResolver extends BindingResolver {
 				case ASTNode.MARKER_ANNOTATION :
 				case ASTNode.NORMAL_ANNOTATION :
 				case ASTNode.SINGLE_MEMBER_ANNOTATION :
+				case ASTNode.GUARDED_PATTERN :
+				case ASTNode.TYPE_PATTERN :
 					org.eclipse.jdt.internal.compiler.ast.Expression compilerExpression = (org.eclipse.jdt.internal.compiler.ast.Expression) this.newAstToOldAst.get(expression);
 					if (compilerExpression != null) {
 						return this.getTypeBinding(compilerExpression.resolvedType);
@@ -768,6 +770,8 @@ class DefaultBindingResolver extends BindingResolver {
 						return this.getTypeBinding(this.scope.getJavaLangString());
 					}
 					break;
+				case ASTNode.NULL_PATTERN :
+					return null;
 				case ASTNode.BOOLEAN_LITERAL :
 				case ASTNode.NULL_LITERAL :
 				case ASTNode.CHARACTER_LITERAL :
