@@ -113,7 +113,7 @@ public final class RewriteEventStore {
 
 		@Override
 		public String toString() {
-			StringBuffer buf= new StringBuffer();
+			StringBuilder buf= new StringBuilder();
 			buf.append(this.parent).append(" - "); //$NON-NLS-1$
 			buf.append(this.childProperty.getId()).append(": "); //$NON-NLS-1$
 			buf.append(this.event).append('\n');
@@ -153,7 +153,7 @@ public final class RewriteEventStore {
 
 		@Override
 		public String toString() {
-			StringBuffer buf= new StringBuffer();
+			StringBuilder buf= new StringBuilder();
 			if (this.isMove) {
 				buf.append("move source: "); //$NON-NLS-1$
 			} else {
@@ -225,7 +225,7 @@ public final class RewriteEventStore {
 
 		@Override
 		public String toString() {
-			StringBuffer buf= new StringBuffer();
+			StringBuilder buf= new StringBuilder();
 			if (this.first != this.last) {
 				buf.append("range ");  //$NON-NLS-1$
 			}
@@ -878,7 +878,7 @@ public final class RewriteEventStore {
 
 	@Override
 	public String toString() {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		for (Iterator iter = this.eventLookup.values().iterator(); iter.hasNext();) {
 			List events = (List) iter.next();
 			for (int i= 0; i < events.size(); i++) {
