@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2014, 2020 Mateusz Matela and others.
+ * Copyright (c) 2014, 2022 Mateusz Matela and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -77,6 +77,23 @@ public class CommentsPreparator extends ASTVisitor {
 			.compile("&(#x[0-9a-fA-F]+)?(#[0-9]+)?(lt)?(gt)?(nbsp)?(amp)?(circ)?(tilde)?(quot)?;"); //$NON-NLS-1$
 	private final static String HTML_ENTITY_REPLACE = "   <> &^~\""; //$NON-NLS-1$
 
+	private final static Pattern SNIPPET_ATTRIBUTE_PATTERN;
+	private final static Pattern SNIPPET_ATTRIBUTES_PATTERN;
+	private final static Pattern SNIPPET_MARKUP_TAG_PATTERN;
+	private final static Pattern SNIPPET_MARKUP_TAG_ARGUMENT_PATTERN;
+	static {
+		String attributeNames = "(class|file|id|lang|region)"; //$NON-NLS-1$
+		String markupTagNames = "(@start|@end|@highlight|@replace|@link)"; //$NON-NLS-1$
+		String ws = "(?>[ \\t]++|[\\r\\n]++[ \\t]*+\\*?)"; // whitespace or line break with optional asterisk //$NON-NLS-1$
+		String attributeValue = "(?>\"[^\"]*\")|(?>\'[^\']*\')|[\\S&&[^\"':]]++"; //$NON-NLS-1$
+		String snippetAttribute = "(?>" + ws + "*" + attributeNames + ws + "*(=)" + ws + "*(" + attributeValue  + "))"; //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$ //$NON-NLS-5$
+		String markupTagArgument = "(?>[ \\t]*\\w+(?>[ \\t]*(=)[ \\t]*(" + attributeValue  + "))?)"; //$NON-NLS-1$ //$NON-NLS-2$
+		SNIPPET_ATTRIBUTE_PATTERN = Pattern.compile(snippetAttribute);
+		SNIPPET_ATTRIBUTES_PATTERN = Pattern.compile(snippetAttribute + "*" + ws + "*(?<colon>:?)"); //$NON-NLS-1$ //$NON-NLS-2$
+		SNIPPET_MARKUP_TAG_ARGUMENT_PATTERN = Pattern.compile(markupTagArgument);
+		SNIPPET_MARKUP_TAG_PATTERN = Pattern.compile(markupTagNames + markupTagArgument + "*"); //$NON-NLS-1$
+	}
+
 	// Param tags list copied from IJavaDocTagConstants in legacy formatter for compatibility.
 	// There were the following comments:
 	// TODO (frederic) should have another name than 'param' for the following tags
@@ -106,11 +123,12 @@ public class CommentsPreparator extends ASTVisitor {
 	/** Index: position within current comment; Value: whether wrapping on special characters is allowed */
 	private boolean[] allowSubstituteWrapping;
 
-	private int noFormatTagOpenStart = -1;
-	private int formatCodeTagOpenEnd = -1;
+	private int noFormatOpenTagStartIndex = -1;
+	private int formatCodeOpenTagEndIndex = -1;
 	private int lastFormatCodeClosingTagIndex = -1;
 	private ArrayList<Integer> commonAttributeAnnotations = new ArrayList<Integer>();
-	private DefaultCodeFormatter commentCodeFormatter;
+	private DefaultCodeFormatter preTagCodeFormatter;
+	private DefaultCodeFormatter snippetCodeFormatter;
 
 	public CommentsPreparator(TokenManager tm, DefaultCodeFormatterOptions options, String sourceLevel) {
 		this.tm = tm;
@@ -163,8 +181,7 @@ public class CommentsPreparator extends ASTVisitor {
 				&& this.tm.countLineBreaksBetween(this.lastLineComment, commentToken) == 1;
 
 		boolean isHeader = this.tm.isInHeader(commentIndex);
-		boolean formattingEnabled = (this.options.comment_format_line_comment && !isHeader)
-				|| (this.options.comment_format_header && isHeader);
+		boolean formattingEnabled = (isHeader ? this.options.comment_format_header : this.options.comment_format_line_comment);
 		if (!formattingEnabled) {
 			preserveWhitespace(commentToken, commentIndex);
 			if (isContinuation) {
@@ -205,6 +222,7 @@ public class CommentsPreparator extends ASTVisitor {
 		} else {
 			commentToken.setInternalStructure(structure);
 			handleCompilerTags(commentToken, commentIndex);
+			handleSnippetMarkupTags(commentToken);
 			preserveWhitespace(commentToken, commentIndex);
 			this.lastLineComment = commentToken;
 			this.lastLineCommentPosition = positionInLine;
@@ -313,6 +331,25 @@ public class CommentsPreparator extends ASTVisitor {
 		}
 	}
 
+	private void handleSnippetMarkupTags(Token commentToken) {
+		String commentText = this.tm.toString(commentToken);
+
+		Matcher m = SNIPPET_MARKUP_TAG_PATTERN.matcher(commentText);
+		while (m.find()) {
+			Matcher m2 = SNIPPET_MARKUP_TAG_ARGUMENT_PATTERN.matcher(m.group());
+			if (!m2.find())
+				continue;
+			this.commentStructure = commentToken.getInternalStructure();
+			this.ctm = new TokenManager(this.commentStructure, this.tm);
+			if (commentToken.tokenType != TokenNameCOMMENT_LINE)
+				continue;
+			do {
+				handleFoundAssignment(m2, 1, commentToken.originalStart + m.start());
+				handleFoundStringLiteral(m2, 2, commentToken.originalStart + m.start());
+			} while (m2.find());
+		}
+	}
+
 	private List<Token> findStringLiteralsInLine(int lastTokenIndex) {
 		List<Token> stringLiterals = new ArrayList<>();
 		Token previous = this.tm.get(lastTokenIndex);
@@ -382,8 +419,7 @@ public class CommentsPreparator extends ASTVisitor {
 			return;
 
 		boolean isHeader = this.tm.isInHeader(commentIndex);
-		boolean formattingEnabled = (this.options.comment_format_block_comment && !isHeader)
-				|| (this.options.comment_format_header && isHeader);
+		boolean formattingEnabled = (isHeader ? this.options.comment_format_header : this.options.comment_format_block_comment);
 		if (this.tm.charAt(commentToken.originalStart + 2) == '-') {
 			if (commentToken.getLineBreaksBefore() > 0 || commentIndex == 0
 					|| this.tm.get(commentIndex - 1).getLineBreaksAfter() > 0) {
@@ -540,8 +576,8 @@ public class CommentsPreparator extends ASTVisitor {
 
 	@Override
 	public boolean visit(Javadoc node) {
-		this.noFormatTagOpenStart = -1;
-		this.formatCodeTagOpenEnd = -1;
+		this.noFormatOpenTagStartIndex = -1;
+		this.formatCodeOpenTagEndIndex = -1;
 		this.lastFormatCodeClosingTagIndex = -1;
 		this.commonAttributeAnnotations.clear();
 		this.ctm = null;
@@ -560,8 +596,7 @@ public class CommentsPreparator extends ASTVisitor {
 			return false;
 
 		boolean isHeader = this.tm.isInHeader(commentIndex);
-		boolean formattingEnabled = (this.options.comment_format_javadoc_comment && !isHeader)
-				|| (this.options.comment_format_header && isHeader);
+		boolean formattingEnabled = (isHeader ? this.options.comment_format_header : this.options.comment_format_javadoc_comment);
 		if (!formattingEnabled || !tokenizeMultilineComment(commentToken)) {
 			commentToken.setInternalStructure(commentToLines(commentToken, -1));
 			return false;
@@ -586,29 +621,32 @@ public class CommentsPreparator extends ASTVisitor {
 	@Override
 	public boolean visit(TagElement node) {
 		String tagName = node.getTagName();
-		if (tagName == null || tagName.length() <= 1)
+		if (tagName == null || tagName.length() <= 1 || !node.tagProperties().isEmpty() /*snippet markup tags*/)
 			return true;
 
 		int startIndex = tokenStartingAt(node.getStartPosition());
-		int nodeEnd = node.getStartPosition() + node.getLength() - 1;
-		while (ScannerHelper.isWhitespace(this.ctm.charAt(nodeEnd)))
-			nodeEnd--;
-		int endIndex = tokenEndingAt(nodeEnd);
-
 		this.ctm.get(startIndex + 1).setWrapPolicy(WrapPolicy.DISABLE_WRAP);
 
 		if (node.getParent() instanceof Javadoc) {
 			assert this.ctm.toString(startIndex).startsWith(tagName);
 
-			Token startTokeen = this.ctm.get(startIndex);
-			if (startIndex > 1)
-				startTokeen.breakBefore();
+			if (startIndex > 1) {
+				this.ctm.get(startIndex).breakBefore();
+			}
 
 			handleHtml(node);
-		}
+			this.ctm.get(tokenStartingAt(node.getStartPosition())).setToEscape(false);
 
-		if (node.isNested() && IMMUTABLE_TAGS.contains(tagName) && startIndex < endIndex) {
-			disableFormatting(startIndex, endIndex, false);
+		} else if (node.isNested() && (IMMUTABLE_TAGS.contains(tagName) || TagElement.TAG_SNIPPET.equals(tagName))) {
+			int endPos = node.getStartPosition() + node.getLength() - 1;
+			int endIndex = this.ctm.findIndex(endPos, -1, false);
+			if (this.ctm.get(endIndex).originalEnd > endPos)
+				endIndex = tokenEndingAt(endPos);
+			if (TagElement.TAG_SNIPPET.equals(tagName)) {
+				handleSnippet(node, startIndex, endIndex);
+			} else {
+				disableFormatting(startIndex, endIndex, false);
+			}
 		}
 		return true;
 	}
@@ -736,8 +774,7 @@ public class CommentsPreparator extends ASTVisitor {
 			}
 		}
 
-		boolean extraIndent = (paramName != null && this.options.comment_indent_parameter_description)
-				|| (paramName == null && this.options.comment_indent_tag_description);
+		boolean extraIndent = (paramName != null ? this.options.comment_indent_parameter_description : this.options.comment_indent_tag_description);
 		for (int i = 2; i < tagTokens.size(); i++) {
 			Token token = tagTokens.get(i);
 			token.setAlign(descriptionAlign);
@@ -783,7 +820,7 @@ public class CommentsPreparator extends ASTVisitor {
 				continue;
 
 			if (matcher.start(2) < matcher.end(2)) {
-				handleFormatCodeTag(startPos, endPos, isOpeningTag);
+				handleFormatCodeTag(node, startPos, endPos, isOpeningTag);
 			}
 			if (this.options.comment_format_html) {
 				if (TagElement.TAG_PARAM.equals(node.getTagName())
@@ -839,16 +876,42 @@ public class CommentsPreparator extends ASTVisitor {
 	private void handleStringLiterals(String text, int textStartPosition) {
 		Matcher matcher = STRING_LITERAL_PATTERN.matcher(text);
 		while (matcher.find()) {
-			int startPosition = textStartPosition + matcher.start();
-			int startIndex = this.ctm.findIndex(startPosition, -1, false);
-			int endPosition = textStartPosition + matcher.end() - 1;
-			int endIndex = this.ctm.findIndex(endPosition, -1, false);
-			if (startIndex != endIndex) {
-				startIndex = tokenStartingAt(startPosition);
-				endIndex = tokenEndingAt(endPosition);
-				disableFormatting(startIndex, endIndex, false);
-			}
+			handleFoundStringLiteral(matcher, 0, textStartPosition);
+		}
+	}
+
+	private void handleFoundStringLiteral(Matcher matcher, int group, int textStartPosition) {
+		if (matcher.start(group) == matcher.end(group))
+			return;
+		int startPosition = textStartPosition + matcher.start(group);
+		int startIndex = this.ctm.findIndex(startPosition, -1, false);
+		int endPosition = textStartPosition + matcher.end(group) - 1;
+		int endIndex = this.ctm.findIndex(endPosition, -1, false);
+		if (startIndex != endIndex) {
+			startIndex = tokenStartingAt(startPosition);
+			endIndex = tokenEndingAt(endPosition);
+			disableFormatting(startIndex, endIndex, false);
+		}
+		if (this.ctm.get(0).tokenType != TokenNameCOMMENT_LINE)
 			noSubstituteWrapping(startPosition, endPosition);
+	}
+
+	private void handleFoundAssignment(Matcher matcher, int group, int textStartPosition) {
+		if (matcher.start(group) == matcher.end(group))
+			return;
+		int equalsPosition = textStartPosition + matcher.start(group);
+		int equalsIndex = tokenStartingAt(equalsPosition);
+		equalsIndex = tokenEndingAt(equalsPosition);
+		assert this.ctm.toString(equalsIndex).equals("="); //$NON-NLS-1$
+		if (this.options.insert_space_before_assignment_operator) {
+			this.ctm.get(equalsIndex).spaceBefore();
+		} else {
+			this.ctm.get(equalsIndex).clearSpaceBefore();
+		}
+		if (this.options.insert_space_after_assignment_operator) {
+			this.ctm.get(equalsIndex + 1).spaceBefore();
+		} else {
+			this.ctm.get(equalsIndex + 1).clearSpaceBefore();
 		}
 	}
 
@@ -885,19 +948,18 @@ public class CommentsPreparator extends ASTVisitor {
 
 	private void handleNoFormatTag(int start, int end, boolean isOpeningTag) {
 		if (isOpeningTag) {
-			if (this.noFormatTagOpenStart < 0)
-				this.noFormatTagOpenStart = start;
-		} else if (this.noFormatTagOpenStart >= 0) {
-			int openingTagIndex = tokenStartingAt(this.noFormatTagOpenStart);
+			if (this.noFormatOpenTagStartIndex < 0)
+				this.noFormatOpenTagStartIndex = tokenStartingAt(start);
+		} else if (this.noFormatOpenTagStartIndex >= 0) {
 			int closingTagIndex = tokenEndingAt(end);
-			if (openingTagIndex < closingTagIndex) {
-				disableFormatting(openingTagIndex, closingTagIndex, true);
+			if (this.noFormatOpenTagStartIndex < closingTagIndex) {
+				disableFormatting(this.noFormatOpenTagStartIndex, closingTagIndex, true);
 			}
-			this.noFormatTagOpenStart = -1;
+			this.noFormatOpenTagStartIndex = -1;
 		}
 	}
 
-	private void handleFormatCodeTag(int startPos, int endPos, boolean isOpeningTag) {
+	private void handleFormatCodeTag(TagElement tagElement, int startPos, int endPos, boolean isOpeningTag) {
 		if (!this.options.comment_format_source) {
 			handleNoFormatTag(startPos, endPos, isOpeningTag);
 			return;
@@ -905,24 +967,107 @@ public class CommentsPreparator extends ASTVisitor {
 
 		// add empty lines before opening and after closing token
 		handleSeparateLineTag(startPos, endPos);
+		int startIndex = tokenStartingAt(startPos);
+		int endTagIndex = tokenEndingAt(endPos);
 		if (isOpeningTag) {
-			int startIndex = tokenStartingAt(startPos);
 			if (startIndex > 1)
 				this.ctm.get(startIndex).putLineBreaksBefore(2);
 
-			if (this.formatCodeTagOpenEnd < 0)
-				this.formatCodeTagOpenEnd = endPos;
-		} else if (this.formatCodeTagOpenEnd >= 0) {
-			int endTagIndex = tokenEndingAt(endPos);
+			if (this.formatCodeOpenTagEndIndex < 0)
+				this.formatCodeOpenTagEndIndex = endTagIndex;
+		} else if (this.formatCodeOpenTagEndIndex >= 0) {
 			if (endTagIndex < this.ctm.size() - 2)
 				this.ctm.get(endTagIndex).putLineBreaksAfter(2);
 
-			formatCode(startPos, endPos);
-			this.formatCodeTagOpenEnd = -1;
+			List<ASTNode> tags = new ArrayList<ASTNode>(tagElement.fragments());
+			tags.removeIf(f -> !(f instanceof TagElement) || !((TagElement) f).isNested());
+			tags.removeIf(f -> f.getStartPosition() > endPos || f.getStartPosition()
+					+ f.getLength() < this.ctm.get(this.formatCodeOpenTagEndIndex).originalStart);
+			if (!tags.isEmpty()) {
+				disableFormatting(this.formatCodeOpenTagEndIndex, startIndex, true);
+
+				String AT_CODE = TagElement.TAG_CODE;
+				String src = this.ctm.getSource();
+				tags.removeIf(f -> !((TagElement) f).getTagName().equals(AT_CODE));
+				for (ASTNode tagNode : tags) {
+					TagElement tag = (TagElement) tagNode;
+					if (tag.getTagName().equals(AT_CODE)) {
+						int nameEndPos = src.indexOf(AT_CODE, tag.getStartPosition()) + AT_CODE.length() - 1;
+						// int closingBracePos = src.lastIndexOf('}', tag.getStartPosition() + tag.getLength());
+						// TODO bug 570137 workaround
+						int closingBracePos = tag.getStartPosition() + 1;
+						for (int braces = 1; braces > 0 && closingBracePos < src.length(); closingBracePos++) {
+							if (src.charAt(closingBracePos) == '{')
+								braces++;
+							if (src.charAt(closingBracePos) == '}')
+								braces--;
+						}
+						closingBracePos--;
+
+						if (formatCode(tokenEndingAt(nameEndPos), tokenStartingAt(closingBracePos), false)) {
+							int closingIndex = tokenStartingAt(closingBracePos);
+							Token t = this.ctm.get(closingIndex);
+							this.commentStructure.set(closingIndex,
+									new Token(t, t.originalStart, t.originalEnd, TokenNameCOMMENT_JAVADOC));
+							boolean allowAnnotationAtLineStart = CompilerOptions.versionToJdkLevel(
+									this.sourceLevel) > CompilerOptions.versionToJdkLevel(CompilerOptions.VERSION_14);
+							for (int i = tokenEndingAt(nameEndPos) + 1; i < closingIndex; i++) {
+								t = this.ctm.get(i);
+								if (this.ctm.charAt(t.originalStart) == '@') {
+									if (allowAnnotationAtLineStart) {
+										t.setToEscape(false);
+									} else {
+										t.clearLineBreaksBefore();
+										t.spaceBefore();
+										this.ctm.get(i - 1).clearLineBreaksAfter();
+									}
+								}
+							}
+						}
+					}
+				}
+			} else if (this.formatCodeOpenTagEndIndex >= startIndex - 1
+					|| !formatCode(this.formatCodeOpenTagEndIndex, startIndex, false)) {
+				disableFormattingExclusively(this.formatCodeOpenTagEndIndex, startIndex);
+			}
+			this.formatCodeOpenTagEndIndex = -1;
 			this.lastFormatCodeClosingTagIndex = this.ctm.findIndex(startPos, -1, true);
 		}
 	}
 
+	private void handleSnippet(TagElement node, int startIndex, int endIndex) {
+		Token startToken = this.ctm.get(startIndex), endToken = this.ctm.get(endIndex);
+		startToken.breakBefore();
+		endToken.breakAfter();
+
+		String lang = null;
+		boolean isInline = false;
+		int snippetTextStartPos = startToken.originalEnd + 1;
+		String snippetText = this.ctm.getSource().substring(snippetTextStartPos, endToken.originalEnd + 1);
+		Matcher m = SNIPPET_ATTRIBUTES_PATTERN.matcher(snippetText);
+		if (m.find() && m.start() == 0) {
+			isInline = !m.group("colon").isEmpty(); //$NON-NLS-1$
+			Matcher m2 = SNIPPET_ATTRIBUTE_PATTERN.matcher(snippetText);
+			while (m2.find()) {
+				handleFoundAssignment(m2, 2, snippetTextStartPos);
+				handleFoundStringLiteral(m2, 3, snippetTextStartPos);
+				if (m2.group(1).equals("lang")) //$NON-NLS-1$
+					lang = m2.group(3);
+			}
+		}
+
+		List<ASTNode> fragments = node.fragments();
+		if (isInline && !fragments.isEmpty()) {
+			int openingIndex = this.ctm.firstIndexBefore(fragments.get(0), -1);
+			int closingIndex = tokenStartingAt(endToken.originalEnd);
+			this.ctm.get(closingIndex).breakBefore();
+			boolean formatted = (lang == null || lang.matches("['\"]?java['\"]?")) //$NON-NLS-1$
+					&& formatCode(openingIndex, closingIndex, true);
+			if (!formatted)
+				disableFormattingExclusively(openingIndex, closingIndex);
+		}
+	}
+
 	private void fixJavadocTagAlign(Token baseToken, int fixFirstIndex) {
 		for (int i = fixFirstIndex; i < this.ctm.size() - 1; i++) {
 			Token token = this.ctm.get(i);
@@ -1167,30 +1312,27 @@ public class CommentsPreparator extends ASTVisitor {
 		}
 	}
 
-	private void formatCode(int javadocNoFormatCloseStart, int javadocNoFormatCloseEnd) {
-		int openingTagLastIndex = tokenEndingAt(this.formatCodeTagOpenEnd);
-		int closingTagFirstIndex = tokenStartingAt(javadocNoFormatCloseStart);
-
-		int codeStartPosition = this.formatCodeTagOpenEnd + 1;
-		int codeEndPosition = javadocNoFormatCloseStart - 1;
+	private boolean formatCode(int openingIndex, int closingIndex, boolean snippetTag) {
+		int codeStartPosition = this.ctm.get(openingIndex).originalEnd + 1;
+		int codeEndPosition = this.ctm.get(closingIndex).originalStart - 1;
 		StringBuilder codeBuilder = new StringBuilder(codeEndPosition - codeStartPosition + 1);
 		int[] positionMapping = new int[codeEndPosition - codeStartPosition + 1];
 		// ^ index: original source position (minus startPosition), value: position in code string
 		getCodeToFormat(codeStartPosition, codeEndPosition, codeBuilder, positionMapping);
 
-		List<Token> formattedTokens = getCommentCodeFormatter().prepareFormattedCode(codeBuilder.toString());
+		DefaultCodeFormatter formatter = snippetTag ? getSnippetCodeFormatter() : getPreTagCodeFormatter();
+		List<Token> formattedTokens = formatter.prepareFormattedCode(codeBuilder.toString());
 
 		if (formattedTokens == null) {
-			disableFormattingExclusively(openingTagLastIndex, closingTagFirstIndex);
-			return;
+			return false;
 		}
 
 		formattedTokens = translateFormattedTokens(codeStartPosition, formattedTokens, positionMapping, null);
 
-		Token openingToken = this.ctm.get(openingTagLastIndex);
+		Token openingToken = this.ctm.get(openingIndex);
 		for (Token token : formattedTokens)
 			token.setAlign(token.getAlign() + openingToken.getAlign() + openingToken.getIndent());
-		fixJavadocTagAlign(openingToken, closingTagFirstIndex);
+		fixJavadocTagAlign(openingToken, closingIndex);
 
 		// there are too few linebreaks at the start and end
 		Token start = formattedTokens.get(0);
@@ -1198,25 +1340,43 @@ public class CommentsPreparator extends ASTVisitor {
 		Token end = formattedTokens.get(formattedTokens.size() - 1);
 		end.putLineBreaksAfter(end.getLineBreaksAfter() + 1);
 		// and there may be too many line breaks before closing tag
-		this.ctm.get(closingTagFirstIndex).clearLineBreaksBefore();
+		this.ctm.get(closingIndex).clearLineBreaksBefore();
 
-		List<Token> tokensToReplace = this.commentStructure.subList(openingTagLastIndex + 1, closingTagFirstIndex);
+		List<Token> tokensToReplace = this.commentStructure.subList(openingIndex + 1, closingIndex);
 		tokensToReplace.clear();
 		tokensToReplace.addAll(formattedTokens);
+		return true;
 	}
 
-	private DefaultCodeFormatter getCommentCodeFormatter() {
-		if (this.commentCodeFormatter == null) {
+	private DefaultCodeFormatter getPreTagCodeFormatter() {
+		if (this.preTagCodeFormatter == null) {
 			Map<String, String> options2 = this.options.getMap();
 			options2.put(DefaultCodeFormatterConstants.FORMATTER_COMMENT_LINE_LENGTH,
 					String.valueOf(this.options.comment_line_length - this.commentIndent
 							- COMMENT_LINE_SEPARATOR_LENGTH));
+
 			options2.put(DefaultCodeFormatterConstants.FORMATTER_LINE_SPLIT,
 					String.valueOf(this.options.page_width - this.commentIndent - COMMENT_LINE_SEPARATOR_LENGTH));
 			options2.put(CompilerOptions.OPTION_Source, this.sourceLevel);
-			this.commentCodeFormatter = new DefaultCodeFormatter(options2);
+			this.preTagCodeFormatter = new DefaultCodeFormatter(options2);
 		}
-		return this.commentCodeFormatter;
+		return this.preTagCodeFormatter;
+	}
+
+	private DefaultCodeFormatter getSnippetCodeFormatter() {
+		if (this.snippetCodeFormatter == null) {
+			Map<String, String> options2 = this.options.getMap();
+			options2.put(
+					DefaultCodeFormatterConstants.FORMATTER_COMMENT_PRESERVE_WHITE_SPACE_BETWEEN_CODE_AND_LINE_COMMENT,
+					DefaultCodeFormatterConstants.TRUE);
+			options2.put(DefaultCodeFormatterConstants.FORMATTER_COMMENT_LINE_LENGTH, String.valueOf(10000));
+
+			options2.put(DefaultCodeFormatterConstants.FORMATTER_LINE_SPLIT,
+					String.valueOf(this.options.page_width - this.commentIndent - COMMENT_LINE_SEPARATOR_LENGTH));
+			options2.put(CompilerOptions.OPTION_Source, this.sourceLevel);
+			this.snippetCodeFormatter = new DefaultCodeFormatter(options2);
+		}
+		return this.snippetCodeFormatter;
 	}
 
 	private void getCodeToFormat(int startPos, int endPos, StringBuilder sb, int[] posMapping) {
