@@ -523,6 +523,12 @@ public boolean equals(Object obj) {
 	CompilationUnit other = (CompilationUnit)obj;
 	return this.owner.equals(other.owner) && super.equals(obj);
 }
+
+@Override
+public int hashCode() {
+	return Util.combineHashCodes(super.hashCode(), this.owner.hashCode());
+}
+
 /**
  * @see ICompilationUnit#findElements(IJavaElement)
  */
@@ -686,7 +692,7 @@ public char[] getContents() {
 						new IOException(e.getMessage());
 				throw new AbortCompilationUnit(null, ioException, encoding);
 			} else {
-				Util.log(e, Messages.bind(Messages.file_notFound, file.getFullPath().toString()));
+				Util.log(e);
 			}
 			return CharOperation.NO_CHAR;
 		}
@@ -1148,7 +1154,7 @@ public org.eclipse.jdt.core.dom.CompilationUnit makeConsistent(int astLevel, boo
 			return null;
 		}
 	} finally {
-		JavaModelManager.getJavaModelManager().abortOnMissingSource.set(null);
+		JavaModelManager.getJavaModelManager().abortOnMissingSource.remove();
 	}
 }
 /**
