@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -7,13 +7,14 @@
  * https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- * 
+ *
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *******************************************************************************/
 package org.eclipse.jdt.internal.core;
 
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.HashMap;
 import java.util.HashSet;
 
@@ -199,7 +200,7 @@ public void acceptType(char[] packageName, char[] typeName, int modifiers, boole
 			acceptFlags = NameLookup.ACCEPT_INTERFACES;
 			break;
 		default:
-			acceptFlags = NameLookup.ACCEPT_CLASSES;
+			acceptFlags = NameLookup.ACCEPT_CLASSES | NameLookup.ACCEPT_RECORDS ;
 			break;
 	}
 	IType type = null;
@@ -271,6 +272,14 @@ public void acceptField(char[] declaringTypePackageName, char[] declaringTypeNam
 		if(type != null) {
 			try {
 				IField[] fields = type.getFields();
+				if (type.isRecord()) {
+					IField[] comps = type.getRecordComponents();
+					if(comps.length > 0) {
+						IField[] f = fields;
+						fields = Arrays.copyOf(f, f.length + comps.length);
+						System.arraycopy(comps, 0, fields, f.length, comps.length);
+					}
+				}
 				for (int i = 0; i < fields.length; i++) {
 					IField field = fields[i];
 					ISourceRange range = field.getNameRange();
@@ -466,13 +475,13 @@ public void acceptLocalVariable(LocalVariableBinding binding, org.eclipse.jdt.in
 		HashSet existingElements = new HashSet();
 		HashMap knownScopes = new HashMap();
 		parent = this.handleFactory.createElement(binding.declaringScope, local.sourceStart, (ICompilationUnit) unit, existingElements, knownScopes);
-	} else {		
+	} else {
 		parent = findLocalElement(local.sourceStart, binding.declaringScope.methodScope()); // findLocalElement() cannot find local variable
 	}
 	LocalVariable localVar = null;
 	if(parent != null) {
 		String typeSig = null;
-		if (local.type == null || local.type.isTypeNameVar(binding.declaringScope)) {
+		if (local.type == null || (local.type.isTypeNameVar(binding.declaringScope) && !binding.type.isAnonymousType())) {
 			if (local.initialization instanceof CastExpression) {
 				typeSig = Util.typeSignature(((CastExpression) local.initialization).type);
 			} else {
@@ -502,6 +511,17 @@ public void acceptLocalVariable(LocalVariableBinding binding, org.eclipse.jdt.in
 		}
 	}
 }
+
+public void acceptLambdaMethod(MethodBinding binding, org.eclipse.jdt.internal.compiler.env.ICompilationUnit unit) {
+	if(binding.sourceLambda() != null) {
+		HashSet existingElements = new HashSet();
+		HashMap knownScopes = new HashMap();
+		LambdaExpression lambdaExpression = binding.sourceLambda();
+		IJavaElement sourceMethod = this.handleFactory.createElement(lambdaExpression.getScope(), lambdaExpression.sourceStart, (ICompilationUnit) unit, existingElements, knownScopes);
+		addElement(sourceMethod);
+	}
+}
+
 /**
  * Resolve the method
  */
@@ -630,18 +650,43 @@ protected void acceptSourceMethod(
 				addElement(method);
 			}
 		}
+
+		// if we are working with a lambda method
+		if(CharOperation.prefixEquals("lambda$".toCharArray(), selector)) { //$NON-NLS-1$
+			addElement(type.getMethod(name, parameterSignatures));
+		}
 	} catch (JavaModelException e) {
 		return;
 	}
 
 	// if no matches, nothing to report
 	if (this.elementIndex == -1) {
-		// no match was actually found, but a method was originally given -> default constructor
-		addElement(type);
-		if(SelectionEngine.DEBUG){
-			System.out.print("SELECTION - accept type("); //$NON-NLS-1$
-			System.out.print(type.toString());
-			System.out.println(")"); //$NON-NLS-1$
+		try {
+			if (type.isRecord()) {
+				IField comp = type.getRecordComponent(name);
+				if (comp != null) {
+					 if (!Flags.isStatic(comp.getFlags())) {
+						// no match was actually found, but a method was originally given -> default accessor
+						 addElement(comp);
+						 if(SelectionEngine.DEBUG){
+								System.out.print("SELECTION - accept field("); //$NON-NLS-1$
+								System.out.print(comp.toString());
+								System.out.println(")"); //$NON-NLS-1$
+						 }
+					 }
+				}
+			}
+		} catch (JavaModelException e) {
+			// Do Nothing
+		}
+		if (this.elementIndex == -1) {
+			// no match was actually found, but a method was originally given -> default constructor
+			addElement(type);
+			if(SelectionEngine.DEBUG){
+				System.out.print("SELECTION - accept type("); //$NON-NLS-1$
+				System.out.print(type.toString());
+				System.out.println(")"); //$NON-NLS-1$
+			}
 		}
 		return;
 	}
@@ -902,7 +947,7 @@ protected IJavaElement findLocalElement(int pos, MethodScope scope) {
 
 /**
  * This method returns an IMethod element from the given method and declaring type bindings. However,
- * unlike {@link Util#findMethod(IType, char[], String[], boolean)} , this does not require an IType to get 
+ * unlike {@link Util#findMethod(IType, char[], String[], boolean)} , this does not require an IType to get
  * the IMethod element.
  * @param method the given method binding
  * @param signatures the type signatures of the method arguments
