@@ -36,7 +36,7 @@ public abstract class JobManager implements Runnable {
 
 	/* background processing */
 	protected volatile Thread processingThread;
-	protected Job progressJob;
+	protected volatile Job progressJob;
 
 	/* counter indicating whether job execution is enabled or not, disabled if <= 0
 	    it cannot go beyond 1 */
@@ -48,6 +48,8 @@ public abstract class JobManager implements Runnable {
 
 	private int awaitingClients = 0;
 
+	private final Object idleMonitor = new Object();
+
 	/**
 	 * Invoked exactly once, in background, before starting processing any job
 	 */
@@ -62,7 +64,9 @@ public abstract class JobManager implements Runnable {
 		return this.activated ? this.awaitingJobs.size() : 1;
 	}
 	/**
-	 * Answers the first job in the queue, or null if there is no job available
+	 * Answers the first job in the queue, or null if there is no job available or
+	 * index manager is disabled
+	 *
 	 * Until the job has completed, the job manager will keep answering the same job.
 	 */
 	public synchronized IJob currentJob() {
@@ -71,6 +75,19 @@ public abstract class JobManager implements Runnable {
 		}
 		return null;
 	}
+
+	/**
+	 * Answers the first job in the queue, or null if there is no job available,
+	 * independently on job manager enablement state.
+	 * Until the job has completed, the job manager will keep answering the same job.
+	 */
+	public synchronized IJob currentJobForced() {
+		if (!this.awaitingJobs.isEmpty()) {
+			return this.awaitingJobs.get(0);
+		}
+		return null;
+	}
+
 	public synchronized void disable() {
 		this.enableCount--;
 		if (VERBOSE)
@@ -206,6 +223,9 @@ public abstract class JobManager implements Runnable {
 		try {
 			SubMonitor subMonitor = SubMonitor.convert(monitor);
 			if (awaitingJobsCount() > 0) {
+				if (VERBOSE)
+					Util.verbose("-> NOT READY - " + awaitingJobsCount() + " awaiting jobs - " + searchJob);//$NON-NLS-1$ //$NON-NLS-2$
+
 				switch (waitingPolicy) {
 
 					case IJob.ForceImmediate :
@@ -249,11 +269,25 @@ public abstract class JobManager implements Runnable {
 							while ((awaitingJobsCount = awaitingJobsCount()) > 0) {
 								if (waitMonitor.isCanceled() || this.processingThread == null)
 									throw new OperationCanceledException();
-								IJob currentJob = currentJob();
-								// currentJob can be null when jobs have been added to the queue but job manager is not enabled
+
+								boolean shouldDisable = false;
+								IJob currentJob = currentJobForced();
+								if (currentJob != null) {
+									if (!isEnabled()) {
+										if (VERBOSE)
+											Util.verbose("-> NOT READY (" + this.enableCount //$NON-NLS-1$
+													+ ") - enabling indexer to process " //$NON-NLS-1$
+													+ awaitingJobsCount + " jobs - " + searchJob);//$NON-NLS-1$
+										enable();
+										shouldDisable = true;
+									}
+									synchronized (this.idleMonitor) {
+										this.idleMonitor.notifyAll(); // wake up idle sleepers
+									}
+								}
 								if (currentJob != null && currentJob != previousJob) {
 									if (VERBOSE)
-										Util.verbose("-> NOT READY - waiting until ready - " + searchJob);//$NON-NLS-1$
+										Util.verbose("-> NOT READY - waiting until ready  to process " + awaitingJobsCount + " awaiting jobs - " + searchJob);//$NON-NLS-1$ //$NON-NLS-2$
 									String indexing = Messages.bind(Messages.jobmanager_filesToIndex, currentJob.getJobFamily(), Integer.toString(awaitingJobsCount));
 									waitMonitor.subTask(indexing);
 									// ratio of the amount of work relative to the total work
@@ -280,6 +314,12 @@ public abstract class JobManager implements Runnable {
 										}
 									}
 								}
+								if (shouldDisable) {
+									if (VERBOSE)
+										Util.verbose("-> NOT READY (" + this.enableCount + ") - disabling indexer again, still awaiting jobs: " //$NON-NLS-1$ //$NON-NLS-2$
+												+ awaitingJobsCount + " - " + searchJob);//$NON-NLS-1$
+									disable();
+								}
 							}
 						} finally {
 							synchronized(this) {
@@ -385,6 +425,8 @@ public abstract class JobManager implements Runnable {
 						}
 						job = currentJob();
 					}
+					//make sure next index job will schedule new ProgressJob:
+					JobManager.this.progressJob = null;
 					return Status.OK_STATUS;
 				}
 			}
@@ -398,8 +440,9 @@ public abstract class JobManager implements Runnable {
 
 						// must check for new job inside this sync block to avoid timing hole
 						if ((job = currentJob()) == null) {
-							if (this.progressJob != null) {
-								this.progressJob.cancel();
+							Job pJob = this.progressJob;
+							if (pJob != null) {
+								pJob.cancel();
 								this.progressJob = null;
 							}
 							if (idlingStart < 0)
@@ -414,7 +457,9 @@ public abstract class JobManager implements Runnable {
 					if (job == null) {
 						notifyIdle(System.currentTimeMillis() - idlingStart);
 						// just woke up, delay before processing any new jobs, allow some time for the active thread to finish
-						Thread.sleep(500);
+						synchronized (this.idleMonitor) {
+							this.idleMonitor.wait(500); // avoid sleep fixed time
+						}
 						continue;
 					}
 					if (VERBOSE) {
@@ -424,10 +469,11 @@ public abstract class JobManager implements Runnable {
 					try {
 						this.executing = true;
 						if (this.progressJob == null) {
-							this.progressJob = new ProgressJob(Messages.bind(Messages.jobmanager_indexing, "", "")); //$NON-NLS-1$ //$NON-NLS-2$
-							this.progressJob.setPriority(Job.LONG);
-							this.progressJob.setSystem(true);
-							this.progressJob.schedule();
+							ProgressJob pJob = new ProgressJob(Messages.bind(Messages.jobmanager_indexing, "", "")); //$NON-NLS-1$ //$NON-NLS-2$
+							pJob.setPriority(Job.LONG);
+							pJob.setSystem(true);
+							pJob.schedule();
+							this.progressJob = pJob;
 						}
 						/*boolean status = */job.execute(null);
 						//if (status == FAILED) request(job);
@@ -440,7 +486,9 @@ public abstract class JobManager implements Runnable {
 							if (VERBOSE) {
 								Util.verbose("WAITING after job - " + job); //$NON-NLS-1$
 							}
-							Thread.sleep(5);
+							synchronized (this.idleMonitor) {
+								this.idleMonitor.wait(5); // avoid sleep fixed time
+							}
 						}
 					}
 				} catch (InterruptedException e) { // background indexing was interrupted
