@@ -10,10 +10,10 @@
  *******************************************************************************/
 package java.util;
 
-public interface Collection<T> extends Iterable<T> {
-	public Iterator<T> iterator();
+public interface Collection<E> extends Iterable<E> {
+	public Iterator<E> iterator();
 	public int size();
-	public T get(int index);
-	public boolean addAll(Collection<T> c);
-	public T[] toArray(T[] o);
+	public E get(int index);
+	public boolean addAll(Collection<E> c);
+	public <T> T[] toArray(T[] o);
 }
